/** @file ADF4158.h
*
*@par@b Author(s):   Jon Cole
*@par@b Company:     Preco Electronics Copyright &copy; 2014, All Rights Reserved.
*@par@b Processor:   Freescale Kinetis K60 Family (MK61FX512VMJ15)
*@par@b Compiler:    IAR ANSI C/C++ Compiler for ARM
*@par@b IDE:         IAR Embedded Workbench For ARM v6.7 
*@par 
*@par@b Description:
*@par
*   
* Routines for controlling the ADF4158.                         @par
* 
* The ADF4158 implements SPI interface.                          @par
* 
* Values are determined by the ADIsimPLL_V4_1_02 application.
* 
*
*@par@b     Revisions:
* 
* 
*@par@em    Revision 1.0 - 10/17/2015 - JPC     
*           - Initial revision 
*
*/

/* I N C L U D E S ***********************************************************/
#include <ADF4158.h>
#include <IO_Expander.h>
#include <MCP23017.h>
#include <main.h>

/* G L O B A L  V A R I A B L E S ********************************************/



/* L O C A L  V A R I A B L E S **********************************************/




/* L O C A L  F U N C T I O N  P R O T O T Y P E S ***************************/



/* F U N C T I O N  D E C L A R A T I O N S **********************************/


unsigned char ADF4158_Init(uint32 frac_int_val, uint8 device_select)
{  
    uint8 temp = 0;
    
    // Intitialization Sequence:
    // 1. Delay Register
    if(!ADF_WriteReg(DELAY_VAL, device_select))
    {
        return 0;
    }
    
    // 2. Step Register - with STEP_SEL = 0
    if(!ADF_WriteReg(STEP_VAL1, device_select))
    {
        return 0;
    }
     
    // 3. Step Register - with STEP_SEL = 1
    if(!ADF_WriteReg(STEP_VAL2, device_select))
    {
        return 0;
    }
    
    // 4. Deviation Register - with DEV_SEL = 0
    //FrequencyReg = DAQ_END_FREQ_TO_REG(24000, 24000);
    //FrequencyReg = FrequencyReg & 0x0000FFFF;
    if(!ADF_WriteReg(DEVIATION_VAL1, device_select))
    {
        return 0;
    }
    
    // 5. Deviation Register - with DEV_SEL = 1
    if(!ADF_WriteReg(DEVIATION_VAL2, device_select))
    {
        return 0;
    }
    
    // 6. Test Register
    if(!ADF_WriteReg(TEST_VAL, device_select))
    {
        return 0;
    }
    
    // 7. Function Register
    if(!ADF_WriteReg(FUNC_VAL, device_select))
    {
        return 0;
    }
    
    // 8. R-divider Register
    if(!ADF_WriteReg(R_DIV_VAL, device_select))
    {
        return 0;
    }

    // 9. LSB_FRAC Register
    if(!ADF_WriteReg(LSB_FRAC_VAL, device_select))
    {
        return 0;
    }    
   
    // 10. FRAC/INT Register
    if(!ADF_WriteReg(frac_int_val, device_select))
    {
        return 0;
    } 
      
    CyDelay(500);

    // Test the MUX_OUT pin (Lock Detect) for logic 1.
    unsigned char PORTA = 0x00;   
    unsigned char *pPORTA = &PORTA;
    if(MCP_ReadRegister(GPIOA, pPORTA))
    {
        if(device_select == DUT)
        {
            temp = PORTA & ADF_MUX1;
            if(temp == ADF_MUX1)
            {
                return 1;
            }             
        }
        else
        {
            temp = PORTA & ADF_MUX2;
            if(temp == ADF_MUX2)
            {
                return 1;
            }            
        }
    }

    return 0;
  
}

unsigned char ADF_PowerDown(uint8 device_select)
{    
    // Function Register
    if(!ADF_WriteReg(PWR_DWN_VAL, device_select))
    {
        return 0;
    }
     
    return 1; 
}

unsigned char ADF_PowerUp(uint8 device_select)
{    
    // Function Register
    if(!ADF_WriteReg(PWR_UP_VAL, device_select))
    {
        return 0;
    }
     
    return 1; 
}


unsigned char ADF_WriteReg(uint32 data, uint8 device_select)
{
    SPI_SEL_REG_Write(0); 
      
    uint16 Byte1 = (uint16)(data >> 16);
    uint16 Byte2 = (uint16)(data);

    if(!device_select)
    {
        CS_AD1_LOW; // DUT
    }
    else
    {
        CS_AD2_LOW; // TESTER  
    }
    
    SPIM_ADF_WriteTxData(Byte1);
    SPIM_ADF_WriteTxData(Byte2);
    
    unsigned char TxStatus = 0;
    unsigned long TIMEOUT_COUNTER = 5000;
    while(TIMEOUT_COUNTER != 0)
    {
        TIMEOUT_COUNTER--;
        TxStatus = SPIM_ADF_ReadTxStatus();
        if((TxStatus & SPIM_ADF_STS_SPI_DONE) == SPIM_ADF_STS_SPI_DONE)
        {
            break;
        }
    }
    
    if(!device_select)
    {
        CS_AD1_HIGH;    // DUT
    }
    else
    {
        CS_AD2_HIGH;    // TESTER
    }

    if(TIMEOUT_COUNTER == 0)
    {
        return 0; // FAIL
    }
    else
    {
        return 1;
    }
}


/* [] END OF FILE */



