/** @file ADF4158.h
*
*@par@b Author(s):   Jon Cole
*@par@b Company:     Preco Electronics Copyright &copy; 2014, All Rights Reserved.
*@par@b Processor:   Freescale Kinetis K60 Family (MK61FX512VMJ15)
*@par@b Compiler:    IAR ANSI C/C++ Compiler for ARM
*@par@b IDE:         IAR Embedded Workbench For ARM v6.7 
*@par 
*@par@b Description:
*@par
*   
* Routines for controlling the ADF4158.                         @par
* 
* The MPR121 implements I2C interface.                          @par
* 
* Values are determined by the ADIsimPLL_V4_1_02 application.
* 
*
*@par@b     Revisions:
* 
* 
*@par@em    Revision 1.0 - 10/17/2015 - JPC     
*           - Initial revision 
*
*/

#ifndef PLL_IC_H
#define PLL_IC_H 

/* I N C L U D E S ***********************************************************/
#include <project.h>


/* C O N S T A N T S *********************************************************/
    
// Registers
#define FRAC_INT_REG    0x0000
#define LSB_FRAC_REG    0x0001
#define R_DIV_REG       0x0002
#define FUNC_REG        0x0003
#define TEST_REG        0x0004
#define DEVIATION_REG   0x0005
#define STEP_REG        0x0006
#define DELAY_REG       0x0007
    
// Register Values
#define FRAC_INT_VAL    0x30177000  // 24.000 GHz 
#define LSB_FRAC_VAL    0x00000001 
#define R_DIV_VAL       0x0010800A 
#define FUNC_VAL        0x00000843 
#define TEST_VAL        0x81980104 
#define DEVIATION_VAL1  0x00001BFD
#define DEVIATION_VAL2  0x00800005
#define STEP_VAL1       0x0002327E 
#define STEP_VAL2       0x00800006 
#define DELAY_VAL       0x00000007 
    
#define PWR_DWN_VAL     0x00000863 
#define PWR_UP_VAL      0x00000843
    
#define FRAC_INT_VAL_22000MHz   0x30157C00
#define FRAC_INT_VAL_23000MHz   0x30167600
#define FRAC_INT_VAL_24000MHz   0x30177000 
#define FRAC_INT_VAL_25000MHz   0x30186A00
#define FRAC_INT_VAL_26000MHz   0x30196400
    
     
/* I N L I N E  F U N C T I O N  M A C R O S *********************************/
   
  
/* T Y P E  D E F S **********************************************************/

    
/* F U N C T I O N  P R O T O T Y P E S **************************************/
unsigned char ADF4158_Init(uint32, uint8);
unsigned char ADF_WriteReg(uint32, uint8);
unsigned char ADF_PowerDown(uint8);
unsigned char ADF_PowerUp(uint8);

#endif // PLL_IC_H
