/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include <BGT24MTR12.h>
#include <IO_Expander.h>
#include <MCP23017.h>
#include <main.h>

unsigned char BGT_Init(uint8 device_select)
{   
    double TxPower = 0.0;
    
    if(BGT_WriteReg(TX_ON, device_select))
    {   
        CyDelay(250);
        TxPower = GetTxPower(device_select);       
        BGT_WriteReg(TX_OFF, device_select);
    }
    
    if(TxPower > 0.4)
    {
        return 1;
    }
    else
    {
        return 0; 
    }
}

double GetTxPower(uint8 device_select)
{
    volatile double RefPower = 0.0;
    double TxPower = 0.0;
    int32 RawCount = 0; 
    
    // Measure TX power
    if(BGT_WriteReg(TX_POWER_OUT, device_select))
    {
        CyDelay(100);
        if(!device_select)
        {
            AnalogMux_FastSelect(BgaAna1_Chan); // DUT
        }
        else
        {
            AnalogMux_FastSelect(BgaAna2_Chan); // TESTER   
        }
        
        ADC_StartConvert();
        while(!ADC_IsEndConversion(ADC_RETURN_STATUS));
        RawCount = ADC_GetResult32();
        if(RawCount > 0)
        {
            TxPower = (double)RawCount*ADC_RESOLUTION;
        }
    }
    
    // Measure REF power   
    if(BGT_WriteReg(REF_POWER_OUT, device_select))
    {   
        CyDelay(100);
        if(!device_select)
        {
            AnalogMux_FastSelect(BgaAna1_Chan); // DUT
        }
        else
        {
            AnalogMux_FastSelect(BgaAna2_Chan); // TESTER   
        }

        ADC_StartConvert();
        while(!ADC_IsEndConversion(ADC_RETURN_STATUS));
        RawCount = ADC_GetResult32();
        if(RawCount > 0)
        {
            RefPower = (double)RawCount*ADC_RESOLUTION;
        }     
    }
    
    TxPower = TxPower - RefPower;
    
    return TxPower;
}

unsigned char BGT_WriteReg(uint16 data, uint8 device_select)
{  
    SPI_SEL_REG_Write(1);
    
    unsigned char TxStatus = 0;
    unsigned long TIMEOUT_COUNTER = 5000;
       
    if(!device_select)
    {
        CS_BGT1_LOW;    // DUT
    }
    else
    {
        CS_BGT2_LOW;    // TESTER  
    }
    
    SPIM_BGT_WriteTxData(data);
    
    while(TIMEOUT_COUNTER != 0)
    {
        TIMEOUT_COUNTER--;
        TxStatus = SPIM_BGT_ReadTxStatus();
        if((TxStatus & SPIM_BGT_STS_SPI_DONE) == SPIM_BGT_STS_SPI_DONE)
        {
            break;
        }
    }
 
    if(!device_select)
    {
        CS_BGT1_HIGH;    // DUT
    }
    else
    {
        CS_BGT2_HIGH;    // TESTER  
    }

    if(TIMEOUT_COUNTER == 0)
    {
        return 0; // FAIL
    }
    else
    {
        return 1;
    }
}

/* [] END OF FILE */
