/*******************************************************************************
* File Name: AnalogMux.h
* Version 1.80
*
*  Description:
*    This file contains the constants and function prototypes for the Analog
*    Multiplexer User Module AMux.
*
*   Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_AMUX_AnalogMux_H)
#define CY_AMUX_AnalogMux_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cyfitter_cfg.h"


/***************************************
*        Function Prototypes
***************************************/

void AnalogMux_Start(void) ;
#define AnalogMux_Init() AnalogMux_Start()
void AnalogMux_FastSelect(uint8 channel) ;
/* The Stop, Select, Connect, Disconnect and DisconnectAll functions are declared elsewhere */
/* void AnalogMux_Stop(void); */
/* void AnalogMux_Select(uint8 channel); */
/* void AnalogMux_Connect(uint8 channel); */
/* void AnalogMux_Disconnect(uint8 channel); */
/* void AnalogMux_DisconnectAll(void) */


/***************************************
*         Parameter Constants
***************************************/

#define AnalogMux_CHANNELS  21u
#define AnalogMux_MUXTYPE   1
#define AnalogMux_ATMOSTONE 1

/***************************************
*             API Constants
***************************************/

#define AnalogMux_NULL_CHANNEL 0xFFu
#define AnalogMux_MUX_SINGLE   1
#define AnalogMux_MUX_DIFF     2


/***************************************
*        Conditional Functions
***************************************/

#if AnalogMux_MUXTYPE == AnalogMux_MUX_SINGLE
# if !AnalogMux_ATMOSTONE
#  define AnalogMux_Connect(channel) AnalogMux_Set(channel)
# endif
# define AnalogMux_Disconnect(channel) AnalogMux_Unset(channel)
#else
# if !AnalogMux_ATMOSTONE
void AnalogMux_Connect(uint8 channel) ;
# endif
void AnalogMux_Disconnect(uint8 channel) ;
#endif

#if AnalogMux_ATMOSTONE
# define AnalogMux_Stop() AnalogMux_DisconnectAll()
# define AnalogMux_Select(channel) AnalogMux_FastSelect(channel)
void AnalogMux_DisconnectAll(void) ;
#else
# define AnalogMux_Stop() AnalogMux_Start()
void AnalogMux_Select(uint8 channel) ;
# define AnalogMux_DisconnectAll() AnalogMux_Start()
#endif

#endif /* CY_AMUX_AnalogMux_H */


/* [] END OF FILE */
