/*******************************************************************************
* File Name: ENC1A.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "ENC1A.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 ENC1A__PORT == 15 && ((ENC1A__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: ENC1A_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void ENC1A_Write(uint8 value) 
{
    uint8 staticBits = (ENC1A_DR & (uint8)(~ENC1A_MASK));
    ENC1A_DR = staticBits | ((uint8)(value << ENC1A_SHIFT) & ENC1A_MASK);
}


/*******************************************************************************
* Function Name: ENC1A_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void ENC1A_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(ENC1A_0, mode);
}


/*******************************************************************************
* Function Name: ENC1A_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro ENC1A_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 ENC1A_Read(void) 
{
    return (ENC1A_PS & ENC1A_MASK) >> ENC1A_SHIFT;
}


/*******************************************************************************
* Function Name: ENC1A_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 ENC1A_ReadDataReg(void) 
{
    return (ENC1A_DR & ENC1A_MASK) >> ENC1A_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(ENC1A_INTSTAT) 

    /*******************************************************************************
    * Function Name: ENC1A_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 ENC1A_ClearInterrupt(void) 
    {
        return (ENC1A_INTSTAT & ENC1A_MASK) >> ENC1A_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
