/*******************************************************************************
* File Name: PosPulseCounter.c  
* Version 3.0
*
*  Description:
*     The Counter component consists of a 8, 16, 24 or 32-bit counter with
*     a selectable period between 2 and 2^Width - 1.  
*
*   Note:
*     None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "PosPulseCounter.h"

uint8 PosPulseCounter_initVar = 0u;


/*******************************************************************************
* Function Name: PosPulseCounter_Init
********************************************************************************
* Summary:
*     Initialize to the schematic state
* 
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void PosPulseCounter_Init(void) 
{
        #if (!PosPulseCounter_UsingFixedFunction && !PosPulseCounter_ControlRegRemoved)
            uint8 ctrl;
        #endif /* (!PosPulseCounter_UsingFixedFunction && !PosPulseCounter_ControlRegRemoved) */
        
        #if(!PosPulseCounter_UsingFixedFunction) 
            /* Interrupt State Backup for Critical Region*/
            uint8 PosPulseCounter_interruptState;
        #endif /* (!PosPulseCounter_UsingFixedFunction) */
        
        #if (PosPulseCounter_UsingFixedFunction)
            /* Clear all bits but the enable bit (if it's already set for Timer operation */
            PosPulseCounter_CONTROL &= PosPulseCounter_CTRL_ENABLE;
            
            /* Clear the mode bits for continuous run mode */
            #if (CY_PSOC5A)
                PosPulseCounter_CONTROL2 &= ((uint8)(~PosPulseCounter_CTRL_MODE_MASK));
            #endif /* (CY_PSOC5A) */
            #if (CY_PSOC3 || CY_PSOC5LP)
                PosPulseCounter_CONTROL3 &= ((uint8)(~PosPulseCounter_CTRL_MODE_MASK));                
            #endif /* (CY_PSOC3 || CY_PSOC5LP) */
            /* Check if One Shot mode is enabled i.e. RunMode !=0*/
            #if (PosPulseCounter_RunModeUsed != 0x0u)
                /* Set 3rd bit of Control register to enable one shot mode */
                PosPulseCounter_CONTROL |= PosPulseCounter_ONESHOT;
            #endif /* (PosPulseCounter_RunModeUsed != 0x0u) */
            
            /* Set the IRQ to use the status register interrupts */
            PosPulseCounter_CONTROL2 |= PosPulseCounter_CTRL2_IRQ_SEL;
            
            /* Clear and Set SYNCTC and SYNCCMP bits of RT1 register */
            PosPulseCounter_RT1 &= ((uint8)(~PosPulseCounter_RT1_MASK));
            PosPulseCounter_RT1 |= PosPulseCounter_SYNC;     
                    
            /*Enable DSI Sync all all inputs of the Timer*/
            PosPulseCounter_RT1 &= ((uint8)(~PosPulseCounter_SYNCDSI_MASK));
            PosPulseCounter_RT1 |= PosPulseCounter_SYNCDSI_EN;

        #else
            #if(!PosPulseCounter_ControlRegRemoved)
            /* Set the default compare mode defined in the parameter */
            ctrl = PosPulseCounter_CONTROL & ((uint8)(~PosPulseCounter_CTRL_CMPMODE_MASK));
            PosPulseCounter_CONTROL = ctrl | PosPulseCounter_DEFAULT_COMPARE_MODE;
            
            /* Set the default capture mode defined in the parameter */
            ctrl = PosPulseCounter_CONTROL & ((uint8)(~PosPulseCounter_CTRL_CAPMODE_MASK));
            
            #if( 0 != PosPulseCounter_CAPTURE_MODE_CONF)
                PosPulseCounter_CONTROL = ctrl | PosPulseCounter_DEFAULT_CAPTURE_MODE;
            #else
                PosPulseCounter_CONTROL = ctrl;
            #endif /* 0 != PosPulseCounter_CAPTURE_MODE */ 
            
            #endif /* (!PosPulseCounter_ControlRegRemoved) */
        #endif /* (PosPulseCounter_UsingFixedFunction) */
        
        /* Clear all data in the FIFO's */
        #if (!PosPulseCounter_UsingFixedFunction)
            PosPulseCounter_ClearFIFO();
        #endif /* (!PosPulseCounter_UsingFixedFunction) */
        
        /* Set Initial values from Configuration */
        PosPulseCounter_WritePeriod(PosPulseCounter_INIT_PERIOD_VALUE);
        #if (!(PosPulseCounter_UsingFixedFunction && (CY_PSOC5A)))
            PosPulseCounter_WriteCounter(PosPulseCounter_INIT_COUNTER_VALUE);
        #endif /* (!(PosPulseCounter_UsingFixedFunction && (CY_PSOC5A))) */
        PosPulseCounter_SetInterruptMode(PosPulseCounter_INIT_INTERRUPTS_MASK);
        
        #if (!PosPulseCounter_UsingFixedFunction)
            /* Read the status register to clear the unwanted interrupts */
            (void)PosPulseCounter_ReadStatusRegister();
            /* Set the compare value (only available to non-fixed function implementation */
            PosPulseCounter_WriteCompare(PosPulseCounter_INIT_COMPARE_VALUE);
            /* Use the interrupt output of the status register for IRQ output */
            
            /* CyEnterCriticalRegion and CyExitCriticalRegion are used to mark following region critical*/
            /* Enter Critical Region*/
            PosPulseCounter_interruptState = CyEnterCriticalSection();
            
            PosPulseCounter_STATUS_AUX_CTRL |= PosPulseCounter_STATUS_ACTL_INT_EN_MASK;
            
            /* Exit Critical Region*/
            CyExitCriticalSection(PosPulseCounter_interruptState);
            
        #endif /* (!PosPulseCounter_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: PosPulseCounter_Enable
********************************************************************************
* Summary:
*     Enable the Counter
* 
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Side Effects: 
*   If the Enable mode is set to Hardware only then this function has no effect 
*   on the operation of the counter.
*
*******************************************************************************/
void PosPulseCounter_Enable(void) 
{
    /* Globally Enable the Fixed Function Block chosen */
    #if (PosPulseCounter_UsingFixedFunction)
        PosPulseCounter_GLOBAL_ENABLE |= PosPulseCounter_BLOCK_EN_MASK;
        PosPulseCounter_GLOBAL_STBY_ENABLE |= PosPulseCounter_BLOCK_STBY_EN_MASK;
    #endif /* (PosPulseCounter_UsingFixedFunction) */  
        
    /* Enable the counter from the control register  */
    /* If Fixed Function then make sure Mode is set correctly */
    /* else make sure reset is clear */
    #if(!PosPulseCounter_ControlRegRemoved || PosPulseCounter_UsingFixedFunction)
        PosPulseCounter_CONTROL |= PosPulseCounter_CTRL_ENABLE;                
    #endif /* (!PosPulseCounter_ControlRegRemoved || PosPulseCounter_UsingFixedFunction) */
    
}


/*******************************************************************************
* Function Name: PosPulseCounter_Start
********************************************************************************
* Summary:
*  Enables the counter for operation 
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Global variables:
*  PosPulseCounter_initVar: Is modified when this function is called for the  
*   first time. Is used to ensure that initialization happens only once.
*
*******************************************************************************/
void PosPulseCounter_Start(void) 
{
    if(PosPulseCounter_initVar == 0u)
    {
        PosPulseCounter_Init();
        
        PosPulseCounter_initVar = 1u; /* Clear this bit for Initialization */        
    }
    
    /* Enable the Counter */
    PosPulseCounter_Enable();        
}


/*******************************************************************************
* Function Name: PosPulseCounter_Stop
********************************************************************************
* Summary:
* Halts the counter, but does not change any modes or disable interrupts.
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
* Side Effects: If the Enable mode is set to Hardware only then this function
*               has no effect on the operation of the counter.
*
*******************************************************************************/
void PosPulseCounter_Stop(void) 
{
    /* Disable Counter */
    #if(!PosPulseCounter_ControlRegRemoved || PosPulseCounter_UsingFixedFunction)
        PosPulseCounter_CONTROL &= ((uint8)(~PosPulseCounter_CTRL_ENABLE));        
    #endif /* (!PosPulseCounter_ControlRegRemoved || PosPulseCounter_UsingFixedFunction) */
    
    /* Globally disable the Fixed Function Block chosen */
    #if (PosPulseCounter_UsingFixedFunction)
        PosPulseCounter_GLOBAL_ENABLE &= ((uint8)(~PosPulseCounter_BLOCK_EN_MASK));
        PosPulseCounter_GLOBAL_STBY_ENABLE &= ((uint8)(~PosPulseCounter_BLOCK_STBY_EN_MASK));
    #endif /* (PosPulseCounter_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: PosPulseCounter_SetInterruptMode
********************************************************************************
* Summary:
* Configures which interrupt sources are enabled to generate the final interrupt
*
* Parameters:  
*  InterruptsMask: This parameter is an or'd collection of the status bits
*                   which will be allowed to generate the counters interrupt.   
*
* Return: 
*  void
*
*******************************************************************************/
void PosPulseCounter_SetInterruptMode(uint8 interruptsMask) 
{
    PosPulseCounter_STATUS_MASK = interruptsMask;
}


/*******************************************************************************
* Function Name: PosPulseCounter_ReadStatusRegister
********************************************************************************
* Summary:
*   Reads the status register and returns it's state. This function should use
*       defined types for the bit-field information as the bits in this
*       register may be permuteable.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) The contents of the status register
*
* Side Effects:
*   Status register bits may be clear on read. 
*
*******************************************************************************/
uint8   PosPulseCounter_ReadStatusRegister(void) 
{
    return PosPulseCounter_STATUS;
}


#if(!PosPulseCounter_ControlRegRemoved)
/*******************************************************************************
* Function Name: PosPulseCounter_ReadControlRegister
********************************************************************************
* Summary:
*   Reads the control register and returns it's state. This function should use
*       defined types for the bit-field information as the bits in this
*       register may be permuteable.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) The contents of the control register
*
*******************************************************************************/
uint8   PosPulseCounter_ReadControlRegister(void) 
{
    return PosPulseCounter_CONTROL;
}


/*******************************************************************************
* Function Name: PosPulseCounter_WriteControlRegister
********************************************************************************
* Summary:
*   Sets the bit-field of the control register.  This function should use
*       defined types for the bit-field information as the bits in this
*       register may be permuteable.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) The contents of the control register
*
*******************************************************************************/
void    PosPulseCounter_WriteControlRegister(uint8 control) 
{
    PosPulseCounter_CONTROL = control;
}

#endif  /* (!PosPulseCounter_ControlRegRemoved) */


#if (!(PosPulseCounter_UsingFixedFunction && (CY_PSOC5A)))
/*******************************************************************************
* Function Name: PosPulseCounter_WriteCounter
********************************************************************************
* Summary:
*   This funtion is used to set the counter to a specific value
*
* Parameters:  
*  counter:  New counter value. 
*
* Return: 
*  void 
*
*******************************************************************************/
void PosPulseCounter_WriteCounter(uint8 counter) \
                                   
{
    #if(PosPulseCounter_UsingFixedFunction)
        /* assert if block is already enabled */
        CYASSERT (0u == (PosPulseCounter_GLOBAL_ENABLE & PosPulseCounter_BLOCK_EN_MASK));
        /* If block is disabled, enable it and then write the counter */
        PosPulseCounter_GLOBAL_ENABLE |= PosPulseCounter_BLOCK_EN_MASK;
        CY_SET_REG16(PosPulseCounter_COUNTER_LSB_PTR, (uint16)counter);
        PosPulseCounter_GLOBAL_ENABLE &= ((uint8)(~PosPulseCounter_BLOCK_EN_MASK));
    #else
        CY_SET_REG8(PosPulseCounter_COUNTER_LSB_PTR, counter);
    #endif /* (PosPulseCounter_UsingFixedFunction) */
}
#endif /* (!(PosPulseCounter_UsingFixedFunction && (CY_PSOC5A))) */


/*******************************************************************************
* Function Name: PosPulseCounter_ReadCounter
********************************************************************************
* Summary:
* Returns the current value of the counter.  It doesn't matter
* if the counter is enabled or running.
*
* Parameters:  
*  void:  
*
* Return: 
*  (uint8) The present value of the counter.
*
*******************************************************************************/
uint8 PosPulseCounter_ReadCounter(void) 
{
    /* Force capture by reading Accumulator */
    /* Must first do a software capture to be able to read the counter */
    /* It is up to the user code to make sure there isn't already captured data in the FIFO */
    #if(PosPulseCounter_UsingFixedFunction)
		(void)CY_GET_REG16(PosPulseCounter_COUNTER_LSB_PTR);
	#else
		(void)CY_GET_REG8(PosPulseCounter_COUNTER_LSB_PTR_8BIT);
	#endif/* (PosPulseCounter_UsingFixedFunction) */
    
    /* Read the data from the FIFO (or capture register for Fixed Function)*/
    #if(PosPulseCounter_UsingFixedFunction)
        return ((uint8)CY_GET_REG16(PosPulseCounter_STATICCOUNT_LSB_PTR));
    #else
        return (CY_GET_REG8(PosPulseCounter_STATICCOUNT_LSB_PTR));
    #endif /* (PosPulseCounter_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: PosPulseCounter_ReadCapture
********************************************************************************
* Summary:
*   This function returns the last value captured.
*
* Parameters:  
*  void
*
* Return: 
*  (uint8) Present Capture value.
*
*******************************************************************************/
uint8 PosPulseCounter_ReadCapture(void) 
{
    #if(PosPulseCounter_UsingFixedFunction)
        return ((uint8)CY_GET_REG16(PosPulseCounter_STATICCOUNT_LSB_PTR));
    #else
        return (CY_GET_REG8(PosPulseCounter_STATICCOUNT_LSB_PTR));
    #endif /* (PosPulseCounter_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: PosPulseCounter_WritePeriod
********************************************************************************
* Summary:
* Changes the period of the counter.  The new period 
* will be loaded the next time terminal count is detected.
*
* Parameters:  
*  period: (uint8) A value of 0 will result in
*         the counter remaining at zero.  
*
* Return: 
*  void
*
*******************************************************************************/
void PosPulseCounter_WritePeriod(uint8 period) 
{
    #if(PosPulseCounter_UsingFixedFunction)
        CY_SET_REG16(PosPulseCounter_PERIOD_LSB_PTR,(uint16)period);
    #else
        CY_SET_REG8(PosPulseCounter_PERIOD_LSB_PTR, period);
    #endif /* (PosPulseCounter_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: PosPulseCounter_ReadPeriod
********************************************************************************
* Summary:
* Reads the current period value without affecting counter operation.
*
* Parameters:  
*  void:  
*
* Return: 
*  (uint8) Present period value.
*
*******************************************************************************/
uint8 PosPulseCounter_ReadPeriod(void) 
{
    #if(PosPulseCounter_UsingFixedFunction)
        return ((uint8)CY_GET_REG16(PosPulseCounter_PERIOD_LSB_PTR));
    #else
        return (CY_GET_REG8(PosPulseCounter_PERIOD_LSB_PTR));
    #endif /* (PosPulseCounter_UsingFixedFunction) */
}


#if (!PosPulseCounter_UsingFixedFunction)
/*******************************************************************************
* Function Name: PosPulseCounter_WriteCompare
********************************************************************************
* Summary:
* Changes the compare value.  The compare output will 
* reflect the new value on the next UDB clock.  The compare output will be 
* driven high when the present counter value compares true based on the 
* configured compare mode setting. 
*
* Parameters:  
*  Compare:  New compare value. 
*
* Return: 
*  void
*
*******************************************************************************/
void PosPulseCounter_WriteCompare(uint8 compare) \
                                   
{
    #if(PosPulseCounter_UsingFixedFunction)
        CY_SET_REG16(PosPulseCounter_COMPARE_LSB_PTR, (uint16)compare);
    #else
        CY_SET_REG8(PosPulseCounter_COMPARE_LSB_PTR, compare);
    #endif /* (PosPulseCounter_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: PosPulseCounter_ReadCompare
********************************************************************************
* Summary:
* Returns the compare value.
*
* Parameters:  
*  void:
*
* Return: 
*  (uint8) Present compare value.
*
*******************************************************************************/
uint8 PosPulseCounter_ReadCompare(void) 
{
    return (CY_GET_REG8(PosPulseCounter_COMPARE_LSB_PTR));
}


#if (PosPulseCounter_COMPARE_MODE_SOFTWARE)
/*******************************************************************************
* Function Name: PosPulseCounter_SetCompareMode
********************************************************************************
* Summary:
*  Sets the software controlled Compare Mode.
*
* Parameters:
*  compareMode:  Compare Mode Enumerated Type.
*
* Return:
*  void
*
*******************************************************************************/
void PosPulseCounter_SetCompareMode(uint8 compareMode) 
{
    /* Clear the compare mode bits in the control register */
    PosPulseCounter_CONTROL &= ((uint8)(~PosPulseCounter_CTRL_CMPMODE_MASK));
    
    /* Write the new setting */
    PosPulseCounter_CONTROL |= compareMode;
}
#endif  /* (PosPulseCounter_COMPARE_MODE_SOFTWARE) */


#if (PosPulseCounter_CAPTURE_MODE_SOFTWARE)
/*******************************************************************************
* Function Name: PosPulseCounter_SetCaptureMode
********************************************************************************
* Summary:
*  Sets the software controlled Capture Mode.
*
* Parameters:
*  captureMode:  Capture Mode Enumerated Type.
*
* Return:
*  void
*
*******************************************************************************/
void PosPulseCounter_SetCaptureMode(uint8 captureMode) 
{
    /* Clear the capture mode bits in the control register */
    PosPulseCounter_CONTROL &= ((uint8)(~PosPulseCounter_CTRL_CAPMODE_MASK));
    
    /* Write the new setting */
    PosPulseCounter_CONTROL |= ((uint8)((uint8)captureMode << PosPulseCounter_CTRL_CAPMODE0_SHIFT));
}
#endif  /* (PosPulseCounter_CAPTURE_MODE_SOFTWARE) */


/*******************************************************************************
* Function Name: PosPulseCounter_ClearFIFO
********************************************************************************
* Summary:
*   This function clears all capture data from the capture FIFO
*
* Parameters:  
*  void:
*
* Return: 
*  None
*
*******************************************************************************/
void PosPulseCounter_ClearFIFO(void) 
{

    while(0u != (PosPulseCounter_ReadStatusRegister() & PosPulseCounter_STATUS_FIFONEMP))
    {
        (void)PosPulseCounter_ReadCapture();
    }

}
#endif  /* (!PosPulseCounter_UsingFixedFunction) */


/* [] END OF FILE */

