/*******************************************************************************
* File Name: SPIM_ADF_PM.c
* Version 2.50
*
* Description:
*  This file contains the setup, control and status commands to support
*  component operations in low power mode.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "SPIM_ADF_PVT.h"

static SPIM_ADF_BACKUP_STRUCT SPIM_ADF_backup =
{
    SPIM_ADF_DISABLED,
    SPIM_ADF_BITCTR_INIT,
};


/*******************************************************************************
* Function Name: SPIM_ADF_SaveConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void SPIM_ADF_SaveConfig(void) 
{

}


/*******************************************************************************
* Function Name: SPIM_ADF_RestoreConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void SPIM_ADF_RestoreConfig(void) 
{

}


/*******************************************************************************
* Function Name: SPIM_ADF_Sleep
********************************************************************************
*
* Summary:
*  Prepare SPIM Component goes to sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  SPIM_ADF_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SPIM_ADF_Sleep(void) 
{
    /* Save components enable state */
    SPIM_ADF_backup.enableState = ((uint8) SPIM_ADF_IS_ENABLED);

    SPIM_ADF_Stop();
}


/*******************************************************************************
* Function Name: SPIM_ADF_Wakeup
********************************************************************************
*
* Summary:
*  Prepare SPIM Component to wake up.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  SPIM_ADF_backup - used when non-retention registers are restored.
*  SPIM_ADF_txBufferWrite - modified every function call - resets to
*  zero.
*  SPIM_ADF_txBufferRead - modified every function call - resets to
*  zero.
*  SPIM_ADF_rxBufferWrite - modified every function call - resets to
*  zero.
*  SPIM_ADF_rxBufferRead - modified every function call - resets to
*  zero.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SPIM_ADF_Wakeup(void) 
{
    #if(SPIM_ADF_RX_SOFTWARE_BUF_ENABLED)
        SPIM_ADF_rxBufferFull  = 0u;
        SPIM_ADF_rxBufferRead  = 0u;
        SPIM_ADF_rxBufferWrite = 0u;
    #endif /* (SPIM_ADF_RX_SOFTWARE_BUF_ENABLED) */

    #if(SPIM_ADF_TX_SOFTWARE_BUF_ENABLED)
        SPIM_ADF_txBufferFull  = 0u;
        SPIM_ADF_txBufferRead  = 0u;
        SPIM_ADF_txBufferWrite = 0u;
    #endif /* (SPIM_ADF_TX_SOFTWARE_BUF_ENABLED) */

    /* Clear any data from the RX and TX FIFO */
    SPIM_ADF_ClearFIFO();

    /* Restore components block enable state */
    if(0u != SPIM_ADF_backup.enableState)
    {
        SPIM_ADF_Enable();
    }
}


/* [] END OF FILE */
