/*******************************************************************************
* File Name: SPIM_BGT_PM.c
* Version 2.50
*
* Description:
*  This file contains the setup, control and status commands to support
*  component operations in low power mode.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "SPIM_BGT_PVT.h"

static SPIM_BGT_BACKUP_STRUCT SPIM_BGT_backup =
{
    SPIM_BGT_DISABLED,
    SPIM_BGT_BITCTR_INIT,
};


/*******************************************************************************
* Function Name: SPIM_BGT_SaveConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void SPIM_BGT_SaveConfig(void) 
{

}


/*******************************************************************************
* Function Name: SPIM_BGT_RestoreConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void SPIM_BGT_RestoreConfig(void) 
{

}


/*******************************************************************************
* Function Name: SPIM_BGT_Sleep
********************************************************************************
*
* Summary:
*  Prepare SPIM Component goes to sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  SPIM_BGT_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SPIM_BGT_Sleep(void) 
{
    /* Save components enable state */
    SPIM_BGT_backup.enableState = ((uint8) SPIM_BGT_IS_ENABLED);

    SPIM_BGT_Stop();
}


/*******************************************************************************
* Function Name: SPIM_BGT_Wakeup
********************************************************************************
*
* Summary:
*  Prepare SPIM Component to wake up.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  SPIM_BGT_backup - used when non-retention registers are restored.
*  SPIM_BGT_txBufferWrite - modified every function call - resets to
*  zero.
*  SPIM_BGT_txBufferRead - modified every function call - resets to
*  zero.
*  SPIM_BGT_rxBufferWrite - modified every function call - resets to
*  zero.
*  SPIM_BGT_rxBufferRead - modified every function call - resets to
*  zero.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SPIM_BGT_Wakeup(void) 
{
    #if(SPIM_BGT_RX_SOFTWARE_BUF_ENABLED)
        SPIM_BGT_rxBufferFull  = 0u;
        SPIM_BGT_rxBufferRead  = 0u;
        SPIM_BGT_rxBufferWrite = 0u;
    #endif /* (SPIM_BGT_RX_SOFTWARE_BUF_ENABLED) */

    #if(SPIM_BGT_TX_SOFTWARE_BUF_ENABLED)
        SPIM_BGT_txBufferFull  = 0u;
        SPIM_BGT_txBufferRead  = 0u;
        SPIM_BGT_txBufferWrite = 0u;
    #endif /* (SPIM_BGT_TX_SOFTWARE_BUF_ENABLED) */

    /* Clear any data from the RX and TX FIFO */
    SPIM_BGT_ClearFIFO();

    /* Restore components block enable state */
    if(0u != SPIM_BGT_backup.enableState)
    {
        SPIM_BGT_Enable();
    }
}


/* [] END OF FILE */
