/*******************************************************************************
* File Name: SPIM_PLL_PM.c
* Version 2.50
*
* Description:
*  This file contains the setup, control and status commands to support
*  component operations in low power mode.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "SPIM_PLL_PVT.h"

static SPIM_PLL_BACKUP_STRUCT SPIM_PLL_backup =
{
    SPIM_PLL_DISABLED,
    SPIM_PLL_BITCTR_INIT,
};


/*******************************************************************************
* Function Name: SPIM_PLL_SaveConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void SPIM_PLL_SaveConfig(void) 
{

}


/*******************************************************************************
* Function Name: SPIM_PLL_RestoreConfig
********************************************************************************
*
* Summary:
*  Empty function. Included for consistency with other components.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void SPIM_PLL_RestoreConfig(void) 
{

}


/*******************************************************************************
* Function Name: SPIM_PLL_Sleep
********************************************************************************
*
* Summary:
*  Prepare SPIM Component goes to sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  SPIM_PLL_backup - modified when non-retention registers are saved.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SPIM_PLL_Sleep(void) 
{
    /* Save components enable state */
    SPIM_PLL_backup.enableState = ((uint8) SPIM_PLL_IS_ENABLED);

    SPIM_PLL_Stop();
}


/*******************************************************************************
* Function Name: SPIM_PLL_Wakeup
********************************************************************************
*
* Summary:
*  Prepare SPIM Component to wake up.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  SPIM_PLL_backup - used when non-retention registers are restored.
*  SPIM_PLL_txBufferWrite - modified every function call - resets to
*  zero.
*  SPIM_PLL_txBufferRead - modified every function call - resets to
*  zero.
*  SPIM_PLL_rxBufferWrite - modified every function call - resets to
*  zero.
*  SPIM_PLL_rxBufferRead - modified every function call - resets to
*  zero.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void SPIM_PLL_Wakeup(void) 
{
    #if(SPIM_PLL_RX_SOFTWARE_BUF_ENABLED)
        SPIM_PLL_rxBufferFull  = 0u;
        SPIM_PLL_rxBufferRead  = 0u;
        SPIM_PLL_rxBufferWrite = 0u;
    #endif /* (SPIM_PLL_RX_SOFTWARE_BUF_ENABLED) */

    #if(SPIM_PLL_TX_SOFTWARE_BUF_ENABLED)
        SPIM_PLL_txBufferFull  = 0u;
        SPIM_PLL_txBufferRead  = 0u;
        SPIM_PLL_txBufferWrite = 0u;
    #endif /* (SPIM_PLL_TX_SOFTWARE_BUF_ENABLED) */

    /* Clear any data from the RX and TX FIFO */
    SPIM_PLL_ClearFIFO();

    /* Restore components block enable state */
    if(0u != SPIM_PLL_backup.enableState)
    {
        SPIM_PLL_Enable();
    }
}


/* [] END OF FILE */
