/*******************************************************************************
* File Name: SingleWireCommTimer.h
* Version 2.70
*
*  Description:
*     Contains the function prototypes and constants available to the timer
*     user module.
*
*   Note:
*     None
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_Timer_v2_60_SingleWireCommTimer_H)
#define CY_Timer_v2_60_SingleWireCommTimer_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

extern uint8 SingleWireCommTimer_initVar;

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component Timer_v2_70 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */


/**************************************
*           Parameter Defaults
**************************************/

#define SingleWireCommTimer_Resolution                 8u
#define SingleWireCommTimer_UsingFixedFunction         0u
#define SingleWireCommTimer_UsingHWCaptureCounter      0u
#define SingleWireCommTimer_SoftwareCaptureMode        0u
#define SingleWireCommTimer_SoftwareTriggerMode        0u
#define SingleWireCommTimer_UsingHWEnable              0u
#define SingleWireCommTimer_EnableTriggerMode          0u
#define SingleWireCommTimer_InterruptOnCaptureCount    1u
#define SingleWireCommTimer_RunModeUsed                0u
#define SingleWireCommTimer_ControlRegRemoved          0u

#if defined(SingleWireCommTimer_TimerUDB_sCTRLReg_SyncCtl_ctrlreg__CONTROL_REG)
    #define SingleWireCommTimer_UDB_CONTROL_REG_REMOVED            (0u)
#elif  (SingleWireCommTimer_UsingFixedFunction)
    #define SingleWireCommTimer_UDB_CONTROL_REG_REMOVED            (0u)
#else 
    #define SingleWireCommTimer_UDB_CONTROL_REG_REMOVED            (1u)
#endif /* End SingleWireCommTimer_TimerUDB_sCTRLReg_SyncCtl_ctrlreg__CONTROL_REG */


/***************************************
*       Type defines
***************************************/


/**************************************************************************
 * Sleep Wakeup Backup structure for Timer Component
 *************************************************************************/
typedef struct
{
    uint8 TimerEnableState;
    #if(!SingleWireCommTimer_UsingFixedFunction)

        uint8 TimerUdb;
        uint8 InterruptMaskValue;
        #if (SingleWireCommTimer_UsingHWCaptureCounter)
            uint8 TimerCaptureCounter;
        #endif /* variable declarations for backing up non retention registers in CY_UDB_V1 */

        #if (!SingleWireCommTimer_UDB_CONTROL_REG_REMOVED)
            uint8 TimerControlRegister;
        #endif /* variable declaration for backing up enable state of the Timer */
    #endif /* define backup variables only for UDB implementation. Fixed function registers are all retention */

}SingleWireCommTimer_backupStruct;


/***************************************
*       Function Prototypes
***************************************/

void    SingleWireCommTimer_Start(void) ;
void    SingleWireCommTimer_Stop(void) ;

void    SingleWireCommTimer_SetInterruptMode(uint8 interruptMode) ;
uint8   SingleWireCommTimer_ReadStatusRegister(void) ;
/* Deprecated function. Do not use this in future. Retained for backward compatibility */
#define SingleWireCommTimer_GetInterruptSource() SingleWireCommTimer_ReadStatusRegister()

#if(!SingleWireCommTimer_UDB_CONTROL_REG_REMOVED)
    uint8   SingleWireCommTimer_ReadControlRegister(void) ;
    void    SingleWireCommTimer_WriteControlRegister(uint8 control) ;
#endif /* (!SingleWireCommTimer_UDB_CONTROL_REG_REMOVED) */

uint8  SingleWireCommTimer_ReadPeriod(void) ;
void    SingleWireCommTimer_WritePeriod(uint8 period) ;
uint8  SingleWireCommTimer_ReadCounter(void) ;
void    SingleWireCommTimer_WriteCounter(uint8 counter) ;
uint8  SingleWireCommTimer_ReadCapture(void) ;
void    SingleWireCommTimer_SoftwareCapture(void) ;

#if(!SingleWireCommTimer_UsingFixedFunction) /* UDB Prototypes */
    #if (SingleWireCommTimer_SoftwareCaptureMode)
        void    SingleWireCommTimer_SetCaptureMode(uint8 captureMode) ;
    #endif /* (!SingleWireCommTimer_UsingFixedFunction) */

    #if (SingleWireCommTimer_SoftwareTriggerMode)
        void    SingleWireCommTimer_SetTriggerMode(uint8 triggerMode) ;
    #endif /* (SingleWireCommTimer_SoftwareTriggerMode) */

    #if (SingleWireCommTimer_EnableTriggerMode)
        void    SingleWireCommTimer_EnableTrigger(void) ;
        void    SingleWireCommTimer_DisableTrigger(void) ;
    #endif /* (SingleWireCommTimer_EnableTriggerMode) */


    #if(SingleWireCommTimer_InterruptOnCaptureCount)
        void    SingleWireCommTimer_SetInterruptCount(uint8 interruptCount) ;
    #endif /* (SingleWireCommTimer_InterruptOnCaptureCount) */

    #if (SingleWireCommTimer_UsingHWCaptureCounter)
        void    SingleWireCommTimer_SetCaptureCount(uint8 captureCount) ;
        uint8   SingleWireCommTimer_ReadCaptureCount(void) ;
    #endif /* (SingleWireCommTimer_UsingHWCaptureCounter) */

    void SingleWireCommTimer_ClearFIFO(void) ;
#endif /* UDB Prototypes */

/* Sleep Retention APIs */
void SingleWireCommTimer_Init(void)          ;
void SingleWireCommTimer_Enable(void)        ;
void SingleWireCommTimer_SaveConfig(void)    ;
void SingleWireCommTimer_RestoreConfig(void) ;
void SingleWireCommTimer_Sleep(void)         ;
void SingleWireCommTimer_Wakeup(void)        ;


/***************************************
*   Enumerated Types and Parameters
***************************************/

/* Enumerated Type B_Timer__CaptureModes, Used in Capture Mode */
#define SingleWireCommTimer__B_TIMER__CM_NONE 0
#define SingleWireCommTimer__B_TIMER__CM_RISINGEDGE 1
#define SingleWireCommTimer__B_TIMER__CM_FALLINGEDGE 2
#define SingleWireCommTimer__B_TIMER__CM_EITHEREDGE 3
#define SingleWireCommTimer__B_TIMER__CM_SOFTWARE 4



/* Enumerated Type B_Timer__TriggerModes, Used in Trigger Mode */
#define SingleWireCommTimer__B_TIMER__TM_NONE 0x00u
#define SingleWireCommTimer__B_TIMER__TM_RISINGEDGE 0x04u
#define SingleWireCommTimer__B_TIMER__TM_FALLINGEDGE 0x08u
#define SingleWireCommTimer__B_TIMER__TM_EITHEREDGE 0x0Cu
#define SingleWireCommTimer__B_TIMER__TM_SOFTWARE 0x10u


/***************************************
*    Initialial Parameter Constants
***************************************/

#define SingleWireCommTimer_INIT_PERIOD             255u
#define SingleWireCommTimer_INIT_CAPTURE_MODE       ((uint8)((uint8)3u << SingleWireCommTimer_CTRL_CAP_MODE_SHIFT))
#define SingleWireCommTimer_INIT_TRIGGER_MODE       ((uint8)((uint8)0u << SingleWireCommTimer_CTRL_TRIG_MODE_SHIFT))
#if (SingleWireCommTimer_UsingFixedFunction)
    #define SingleWireCommTimer_INIT_INTERRUPT_MODE (((uint8)((uint8)0u << SingleWireCommTimer_STATUS_TC_INT_MASK_SHIFT)) | \
                                                  ((uint8)((uint8)1 << SingleWireCommTimer_STATUS_CAPTURE_INT_MASK_SHIFT)))
#else
    #define SingleWireCommTimer_INIT_INTERRUPT_MODE (((uint8)((uint8)0u << SingleWireCommTimer_STATUS_TC_INT_MASK_SHIFT)) | \
                                                 ((uint8)((uint8)1 << SingleWireCommTimer_STATUS_CAPTURE_INT_MASK_SHIFT)) | \
                                                 ((uint8)((uint8)0 << SingleWireCommTimer_STATUS_FIFOFULL_INT_MASK_SHIFT)))
#endif /* (SingleWireCommTimer_UsingFixedFunction) */
#define SingleWireCommTimer_INIT_CAPTURE_COUNT      (2u)
#define SingleWireCommTimer_INIT_INT_CAPTURE_COUNT  ((uint8)((uint8)(1u - 1u) << SingleWireCommTimer_CTRL_INTCNT_SHIFT))


/***************************************
*           Registers
***************************************/

#if (SingleWireCommTimer_UsingFixedFunction) /* Implementation Specific Registers and Register Constants */


    /***************************************
    *    Fixed Function Registers
    ***************************************/

    #define SingleWireCommTimer_STATUS         (*(reg8 *) SingleWireCommTimer_TimerHW__SR0 )
    /* In Fixed Function Block Status and Mask are the same register */
    #define SingleWireCommTimer_STATUS_MASK    (*(reg8 *) SingleWireCommTimer_TimerHW__SR0 )
    #define SingleWireCommTimer_CONTROL        (*(reg8 *) SingleWireCommTimer_TimerHW__CFG0)
    #define SingleWireCommTimer_CONTROL2       (*(reg8 *) SingleWireCommTimer_TimerHW__CFG1)
    #define SingleWireCommTimer_CONTROL2_PTR   ( (reg8 *) SingleWireCommTimer_TimerHW__CFG1)
    #define SingleWireCommTimer_RT1            (*(reg8 *) SingleWireCommTimer_TimerHW__RT1)
    #define SingleWireCommTimer_RT1_PTR        ( (reg8 *) SingleWireCommTimer_TimerHW__RT1)

    #if (CY_PSOC3 || CY_PSOC5LP)
        #define SingleWireCommTimer_CONTROL3       (*(reg8 *) SingleWireCommTimer_TimerHW__CFG2)
        #define SingleWireCommTimer_CONTROL3_PTR   ( (reg8 *) SingleWireCommTimer_TimerHW__CFG2)
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */
    #define SingleWireCommTimer_GLOBAL_ENABLE  (*(reg8 *) SingleWireCommTimer_TimerHW__PM_ACT_CFG)
    #define SingleWireCommTimer_GLOBAL_STBY_ENABLE  (*(reg8 *) SingleWireCommTimer_TimerHW__PM_STBY_CFG)

    #define SingleWireCommTimer_CAPTURE_LSB         (* (reg16 *) SingleWireCommTimer_TimerHW__CAP0 )
    #define SingleWireCommTimer_CAPTURE_LSB_PTR       ((reg16 *) SingleWireCommTimer_TimerHW__CAP0 )
    #define SingleWireCommTimer_PERIOD_LSB          (* (reg16 *) SingleWireCommTimer_TimerHW__PER0 )
    #define SingleWireCommTimer_PERIOD_LSB_PTR        ((reg16 *) SingleWireCommTimer_TimerHW__PER0 )
    #define SingleWireCommTimer_COUNTER_LSB         (* (reg16 *) SingleWireCommTimer_TimerHW__CNT_CMP0 )
    #define SingleWireCommTimer_COUNTER_LSB_PTR       ((reg16 *) SingleWireCommTimer_TimerHW__CNT_CMP0 )


    /***************************************
    *    Register Constants
    ***************************************/

    /* Fixed Function Block Chosen */
    #define SingleWireCommTimer_BLOCK_EN_MASK                     SingleWireCommTimer_TimerHW__PM_ACT_MSK
    #define SingleWireCommTimer_BLOCK_STBY_EN_MASK                SingleWireCommTimer_TimerHW__PM_STBY_MSK

    /* Control Register Bit Locations */
    /* Interrupt Count - Not valid for Fixed Function Block */
    #define SingleWireCommTimer_CTRL_INTCNT_SHIFT                  0x00u
    /* Trigger Polarity - Not valid for Fixed Function Block */
    #define SingleWireCommTimer_CTRL_TRIG_MODE_SHIFT               0x00u
    /* Trigger Enable - Not valid for Fixed Function Block */
    #define SingleWireCommTimer_CTRL_TRIG_EN_SHIFT                 0x00u
    /* Capture Polarity - Not valid for Fixed Function Block */
    #define SingleWireCommTimer_CTRL_CAP_MODE_SHIFT                0x00u
    /* Timer Enable - As defined in Register Map, part of TMRX_CFG0 register */
    #define SingleWireCommTimer_CTRL_ENABLE_SHIFT                  0x00u

    /* Control Register Bit Masks */
    #define SingleWireCommTimer_CTRL_ENABLE                        ((uint8)((uint8)0x01u << SingleWireCommTimer_CTRL_ENABLE_SHIFT))

    /* Control2 Register Bit Masks */
    /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define SingleWireCommTimer_CTRL2_IRQ_SEL_SHIFT                 0x00u
    #define SingleWireCommTimer_CTRL2_IRQ_SEL                      ((uint8)((uint8)0x01u << SingleWireCommTimer_CTRL2_IRQ_SEL_SHIFT))

    #if (CY_PSOC5A)
        /* Use CFG1 Mode bits to set run mode */
        /* As defined by Verilog Implementation */
        #define SingleWireCommTimer_CTRL_MODE_SHIFT                 0x01u
        #define SingleWireCommTimer_CTRL_MODE_MASK                 ((uint8)((uint8)0x07u << SingleWireCommTimer_CTRL_MODE_SHIFT))
    #endif /* (CY_PSOC5A) */
    #if (CY_PSOC3 || CY_PSOC5LP)
        /* Control3 Register Bit Locations */
        #define SingleWireCommTimer_CTRL_RCOD_SHIFT        0x02u
        #define SingleWireCommTimer_CTRL_ENBL_SHIFT        0x00u
        #define SingleWireCommTimer_CTRL_MODE_SHIFT        0x00u

        /* Control3 Register Bit Masks */
        #define SingleWireCommTimer_CTRL_RCOD_MASK  ((uint8)((uint8)0x03u << SingleWireCommTimer_CTRL_RCOD_SHIFT)) /* ROD and COD bit masks */
        #define SingleWireCommTimer_CTRL_ENBL_MASK  ((uint8)((uint8)0x80u << SingleWireCommTimer_CTRL_ENBL_SHIFT)) /* HW_EN bit mask */
        #define SingleWireCommTimer_CTRL_MODE_MASK  ((uint8)((uint8)0x03u << SingleWireCommTimer_CTRL_MODE_SHIFT)) /* Run mode bit mask */

        #define SingleWireCommTimer_CTRL_RCOD       ((uint8)((uint8)0x03u << SingleWireCommTimer_CTRL_RCOD_SHIFT))
        #define SingleWireCommTimer_CTRL_ENBL       ((uint8)((uint8)0x80u << SingleWireCommTimer_CTRL_ENBL_SHIFT))
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */

    /*RT1 Synch Constants: Applicable for PSoC3 and PSoC5LP */
    #define SingleWireCommTimer_RT1_SHIFT                       0x04u
    /* Sync TC and CMP bit masks */
    #define SingleWireCommTimer_RT1_MASK                        ((uint8)((uint8)0x03u << SingleWireCommTimer_RT1_SHIFT))
    #define SingleWireCommTimer_SYNC                            ((uint8)((uint8)0x03u << SingleWireCommTimer_RT1_SHIFT))
    #define SingleWireCommTimer_SYNCDSI_SHIFT                   0x00u
    /* Sync all DSI inputs with Mask  */
    #define SingleWireCommTimer_SYNCDSI_MASK                    ((uint8)((uint8)0x0Fu << SingleWireCommTimer_SYNCDSI_SHIFT))
    /* Sync all DSI inputs */
    #define SingleWireCommTimer_SYNCDSI_EN                      ((uint8)((uint8)0x0Fu << SingleWireCommTimer_SYNCDSI_SHIFT))

    #define SingleWireCommTimer_CTRL_MODE_PULSEWIDTH            ((uint8)((uint8)0x01u << SingleWireCommTimer_CTRL_MODE_SHIFT))
    #define SingleWireCommTimer_CTRL_MODE_PERIOD                ((uint8)((uint8)0x02u << SingleWireCommTimer_CTRL_MODE_SHIFT))
    #define SingleWireCommTimer_CTRL_MODE_CONTINUOUS            ((uint8)((uint8)0x00u << SingleWireCommTimer_CTRL_MODE_SHIFT))

    /* Status Register Bit Locations */
    /* As defined in Register Map, part of TMRX_SR0 register */
    #define SingleWireCommTimer_STATUS_TC_SHIFT                 0x07u
    /* As defined in Register Map, part of TMRX_SR0 register, Shared with Compare Status */
    #define SingleWireCommTimer_STATUS_CAPTURE_SHIFT            0x06u
    /* As defined in Register Map, part of TMRX_SR0 register */
    #define SingleWireCommTimer_STATUS_TC_INT_MASK_SHIFT        (SingleWireCommTimer_STATUS_TC_SHIFT - 0x04u)
    /* As defined in Register Map, part of TMRX_SR0 register, Shared with Compare Status */
    #define SingleWireCommTimer_STATUS_CAPTURE_INT_MASK_SHIFT   (SingleWireCommTimer_STATUS_CAPTURE_SHIFT - 0x04u)

    /* Status Register Bit Masks */
    #define SingleWireCommTimer_STATUS_TC                       ((uint8)((uint8)0x01u << SingleWireCommTimer_STATUS_TC_SHIFT))
    #define SingleWireCommTimer_STATUS_CAPTURE                  ((uint8)((uint8)0x01u << SingleWireCommTimer_STATUS_CAPTURE_SHIFT))
    /* Interrupt Enable Bit-Mask for interrupt on TC */
    #define SingleWireCommTimer_STATUS_TC_INT_MASK              ((uint8)((uint8)0x01u << SingleWireCommTimer_STATUS_TC_INT_MASK_SHIFT))
    /* Interrupt Enable Bit-Mask for interrupt on Capture */
    #define SingleWireCommTimer_STATUS_CAPTURE_INT_MASK         ((uint8)((uint8)0x01u << SingleWireCommTimer_STATUS_CAPTURE_INT_MASK_SHIFT))

#else   /* UDB Registers and Register Constants */


    /***************************************
    *           UDB Registers
    ***************************************/

    #define SingleWireCommTimer_STATUS              (* (reg8 *) SingleWireCommTimer_TimerUDB_rstSts_stsreg__STATUS_REG )
    #define SingleWireCommTimer_STATUS_MASK         (* (reg8 *) SingleWireCommTimer_TimerUDB_rstSts_stsreg__MASK_REG)
    #define SingleWireCommTimer_STATUS_AUX_CTRL     (* (reg8 *) SingleWireCommTimer_TimerUDB_rstSts_stsreg__STATUS_AUX_CTL_REG)
    #define SingleWireCommTimer_CONTROL             (* (reg8 *) SingleWireCommTimer_TimerUDB_sCTRLReg_SyncCtl_ctrlreg__CONTROL_REG )
    
    #if(SingleWireCommTimer_Resolution <= 8u) /* 8-bit Timer */
        #define SingleWireCommTimer_CAPTURE_LSB         (* (reg8 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__F0_REG )
        #define SingleWireCommTimer_CAPTURE_LSB_PTR       ((reg8 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__F0_REG )
        #define SingleWireCommTimer_PERIOD_LSB          (* (reg8 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__D0_REG )
        #define SingleWireCommTimer_PERIOD_LSB_PTR        ((reg8 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__D0_REG )
        #define SingleWireCommTimer_COUNTER_LSB         (* (reg8 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__A0_REG )
        #define SingleWireCommTimer_COUNTER_LSB_PTR       ((reg8 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__A0_REG )
    #elif(SingleWireCommTimer_Resolution <= 16u) /* 8-bit Timer */
        #if(CY_PSOC3) /* 8-bit addres space */
            #define SingleWireCommTimer_CAPTURE_LSB         (* (reg16 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__F0_REG )
            #define SingleWireCommTimer_CAPTURE_LSB_PTR       ((reg16 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__F0_REG )
            #define SingleWireCommTimer_PERIOD_LSB          (* (reg16 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__D0_REG )
            #define SingleWireCommTimer_PERIOD_LSB_PTR        ((reg16 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__D0_REG )
            #define SingleWireCommTimer_COUNTER_LSB         (* (reg16 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__A0_REG )
            #define SingleWireCommTimer_COUNTER_LSB_PTR       ((reg16 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__A0_REG )
        #else /* 16-bit address space */
            #define SingleWireCommTimer_CAPTURE_LSB         (* (reg16 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__16BIT_F0_REG )
            #define SingleWireCommTimer_CAPTURE_LSB_PTR       ((reg16 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__16BIT_F0_REG )
            #define SingleWireCommTimer_PERIOD_LSB          (* (reg16 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__16BIT_D0_REG )
            #define SingleWireCommTimer_PERIOD_LSB_PTR        ((reg16 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__16BIT_D0_REG )
            #define SingleWireCommTimer_COUNTER_LSB         (* (reg16 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__16BIT_A0_REG )
            #define SingleWireCommTimer_COUNTER_LSB_PTR       ((reg16 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__16BIT_A0_REG )
        #endif /* CY_PSOC3 */
    #elif(SingleWireCommTimer_Resolution <= 24u)/* 24-bit Timer */
        #define SingleWireCommTimer_CAPTURE_LSB         (* (reg32 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__F0_REG )
        #define SingleWireCommTimer_CAPTURE_LSB_PTR       ((reg32 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__F0_REG )
        #define SingleWireCommTimer_PERIOD_LSB          (* (reg32 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__D0_REG )
        #define SingleWireCommTimer_PERIOD_LSB_PTR        ((reg32 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__D0_REG )
        #define SingleWireCommTimer_COUNTER_LSB         (* (reg32 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__A0_REG )
        #define SingleWireCommTimer_COUNTER_LSB_PTR       ((reg32 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__A0_REG )
    #else /* 32-bit Timer */
        #if(CY_PSOC3 || CY_PSOC5) /* 8-bit address space */
            #define SingleWireCommTimer_CAPTURE_LSB         (* (reg32 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__F0_REG )
            #define SingleWireCommTimer_CAPTURE_LSB_PTR       ((reg32 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__F0_REG )
            #define SingleWireCommTimer_PERIOD_LSB          (* (reg32 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__D0_REG )
            #define SingleWireCommTimer_PERIOD_LSB_PTR        ((reg32 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__D0_REG )
            #define SingleWireCommTimer_COUNTER_LSB         (* (reg32 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__A0_REG )
            #define SingleWireCommTimer_COUNTER_LSB_PTR       ((reg32 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__A0_REG )
        #else /* 32-bit address space */
            #define SingleWireCommTimer_CAPTURE_LSB         (* (reg32 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__32BIT_F0_REG )
            #define SingleWireCommTimer_CAPTURE_LSB_PTR       ((reg32 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__32BIT_F0_REG )
            #define SingleWireCommTimer_PERIOD_LSB          (* (reg32 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__32BIT_D0_REG )
            #define SingleWireCommTimer_PERIOD_LSB_PTR        ((reg32 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__32BIT_D0_REG )
            #define SingleWireCommTimer_COUNTER_LSB         (* (reg32 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__32BIT_A0_REG )
            #define SingleWireCommTimer_COUNTER_LSB_PTR       ((reg32 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__32BIT_A0_REG )
        #endif /* CY_PSOC3 || CY_PSOC5 */ 
    #endif

    #define SingleWireCommTimer_COUNTER_LSB_PTR_8BIT       ((reg8 *) SingleWireCommTimer_TimerUDB_sT8_timerdp_u0__A0_REG )
    
    #if (SingleWireCommTimer_UsingHWCaptureCounter)
        #define SingleWireCommTimer_CAP_COUNT              (*(reg8 *) SingleWireCommTimer_TimerUDB_sCapCount_counter__PERIOD_REG )
        #define SingleWireCommTimer_CAP_COUNT_PTR          ( (reg8 *) SingleWireCommTimer_TimerUDB_sCapCount_counter__PERIOD_REG )
        #define SingleWireCommTimer_CAPTURE_COUNT_CTRL     (*(reg8 *) SingleWireCommTimer_TimerUDB_sCapCount_counter__CONTROL_AUX_CTL_REG )
        #define SingleWireCommTimer_CAPTURE_COUNT_CTRL_PTR ( (reg8 *) SingleWireCommTimer_TimerUDB_sCapCount_counter__CONTROL_AUX_CTL_REG )
    #endif /* (SingleWireCommTimer_UsingHWCaptureCounter) */


    /***************************************
    *       Register Constants
    ***************************************/

    /* Control Register Bit Locations */
    #define SingleWireCommTimer_CTRL_INTCNT_SHIFT              0x00u       /* As defined by Verilog Implementation */
    #define SingleWireCommTimer_CTRL_TRIG_MODE_SHIFT           0x02u       /* As defined by Verilog Implementation */
    #define SingleWireCommTimer_CTRL_TRIG_EN_SHIFT             0x04u       /* As defined by Verilog Implementation */
    #define SingleWireCommTimer_CTRL_CAP_MODE_SHIFT            0x05u       /* As defined by Verilog Implementation */
    #define SingleWireCommTimer_CTRL_ENABLE_SHIFT              0x07u       /* As defined by Verilog Implementation */

    /* Control Register Bit Masks */
    #define SingleWireCommTimer_CTRL_INTCNT_MASK               ((uint8)((uint8)0x03u << SingleWireCommTimer_CTRL_INTCNT_SHIFT))
    #define SingleWireCommTimer_CTRL_TRIG_MODE_MASK            ((uint8)((uint8)0x03u << SingleWireCommTimer_CTRL_TRIG_MODE_SHIFT))
    #define SingleWireCommTimer_CTRL_TRIG_EN                   ((uint8)((uint8)0x01u << SingleWireCommTimer_CTRL_TRIG_EN_SHIFT))
    #define SingleWireCommTimer_CTRL_CAP_MODE_MASK             ((uint8)((uint8)0x03u << SingleWireCommTimer_CTRL_CAP_MODE_SHIFT))
    #define SingleWireCommTimer_CTRL_ENABLE                    ((uint8)((uint8)0x01u << SingleWireCommTimer_CTRL_ENABLE_SHIFT))

    /* Bit Counter (7-bit) Control Register Bit Definitions */
    /* As defined by the Register map for the AUX Control Register */
    #define SingleWireCommTimer_CNTR_ENABLE                    0x20u

    /* Status Register Bit Locations */
    #define SingleWireCommTimer_STATUS_TC_SHIFT                0x00u  /* As defined by Verilog Implementation */
    #define SingleWireCommTimer_STATUS_CAPTURE_SHIFT           0x01u  /* As defined by Verilog Implementation */
    #define SingleWireCommTimer_STATUS_TC_INT_MASK_SHIFT       SingleWireCommTimer_STATUS_TC_SHIFT
    #define SingleWireCommTimer_STATUS_CAPTURE_INT_MASK_SHIFT  SingleWireCommTimer_STATUS_CAPTURE_SHIFT
    #define SingleWireCommTimer_STATUS_FIFOFULL_SHIFT          0x02u  /* As defined by Verilog Implementation */
    #define SingleWireCommTimer_STATUS_FIFONEMP_SHIFT          0x03u  /* As defined by Verilog Implementation */
    #define SingleWireCommTimer_STATUS_FIFOFULL_INT_MASK_SHIFT SingleWireCommTimer_STATUS_FIFOFULL_SHIFT

    /* Status Register Bit Masks */
    /* Sticky TC Event Bit-Mask */
    #define SingleWireCommTimer_STATUS_TC                      ((uint8)((uint8)0x01u << SingleWireCommTimer_STATUS_TC_SHIFT))
    /* Sticky Capture Event Bit-Mask */
    #define SingleWireCommTimer_STATUS_CAPTURE                 ((uint8)((uint8)0x01u << SingleWireCommTimer_STATUS_CAPTURE_SHIFT))
    /* Interrupt Enable Bit-Mask */
    #define SingleWireCommTimer_STATUS_TC_INT_MASK             ((uint8)((uint8)0x01u << SingleWireCommTimer_STATUS_TC_SHIFT))
    /* Interrupt Enable Bit-Mask */
    #define SingleWireCommTimer_STATUS_CAPTURE_INT_MASK        ((uint8)((uint8)0x01u << SingleWireCommTimer_STATUS_CAPTURE_SHIFT))
    /* NOT-Sticky FIFO Full Bit-Mask */
    #define SingleWireCommTimer_STATUS_FIFOFULL                ((uint8)((uint8)0x01u << SingleWireCommTimer_STATUS_FIFOFULL_SHIFT))
    /* NOT-Sticky FIFO Not Empty Bit-Mask */
    #define SingleWireCommTimer_STATUS_FIFONEMP                ((uint8)((uint8)0x01u << SingleWireCommTimer_STATUS_FIFONEMP_SHIFT))
    /* Interrupt Enable Bit-Mask */
    #define SingleWireCommTimer_STATUS_FIFOFULL_INT_MASK       ((uint8)((uint8)0x01u << SingleWireCommTimer_STATUS_FIFOFULL_SHIFT))

    #define SingleWireCommTimer_STATUS_ACTL_INT_EN             0x10u   /* As defined for the ACTL Register */

    /* Datapath Auxillary Control Register definitions */
    #define SingleWireCommTimer_AUX_CTRL_FIFO0_CLR             0x01u   /* As defined by Register map */
    #define SingleWireCommTimer_AUX_CTRL_FIFO1_CLR             0x02u   /* As defined by Register map */
    #define SingleWireCommTimer_AUX_CTRL_FIFO0_LVL             0x04u   /* As defined by Register map */
    #define SingleWireCommTimer_AUX_CTRL_FIFO1_LVL             0x08u   /* As defined by Register map */
    #define SingleWireCommTimer_STATUS_ACTL_INT_EN_MASK        0x10u   /* As defined for the ACTL Register */

#endif /* Implementation Specific Registers and Register Constants */

#endif  /* CY_Timer_v2_30_SingleWireCommTimer_H */


/* [] END OF FILE */
