/*******************************************************************************
* File Name: SpeedMsgTimer.h
* Version 2.70
*
*  Description:
*     Contains the function prototypes and constants available to the timer
*     user module.
*
*   Note:
*     None
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_Timer_v2_60_SpeedMsgTimer_H)
#define CY_Timer_v2_60_SpeedMsgTimer_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

extern uint8 SpeedMsgTimer_initVar;

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component Timer_v2_70 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */


/**************************************
*           Parameter Defaults
**************************************/

#define SpeedMsgTimer_Resolution                 8u
#define SpeedMsgTimer_UsingFixedFunction         1u
#define SpeedMsgTimer_UsingHWCaptureCounter      0u
#define SpeedMsgTimer_SoftwareCaptureMode        0u
#define SpeedMsgTimer_SoftwareTriggerMode        0u
#define SpeedMsgTimer_UsingHWEnable              0u
#define SpeedMsgTimer_EnableTriggerMode          0u
#define SpeedMsgTimer_InterruptOnCaptureCount    0u
#define SpeedMsgTimer_RunModeUsed                0u
#define SpeedMsgTimer_ControlRegRemoved          0u

#if defined(SpeedMsgTimer_TimerUDB_sCTRLReg_SyncCtl_ctrlreg__CONTROL_REG)
    #define SpeedMsgTimer_UDB_CONTROL_REG_REMOVED            (0u)
#elif  (SpeedMsgTimer_UsingFixedFunction)
    #define SpeedMsgTimer_UDB_CONTROL_REG_REMOVED            (0u)
#else 
    #define SpeedMsgTimer_UDB_CONTROL_REG_REMOVED            (1u)
#endif /* End SpeedMsgTimer_TimerUDB_sCTRLReg_SyncCtl_ctrlreg__CONTROL_REG */


/***************************************
*       Type defines
***************************************/


/**************************************************************************
 * Sleep Wakeup Backup structure for Timer Component
 *************************************************************************/
typedef struct
{
    uint8 TimerEnableState;
    #if(!SpeedMsgTimer_UsingFixedFunction)

        uint8 TimerUdb;
        uint8 InterruptMaskValue;
        #if (SpeedMsgTimer_UsingHWCaptureCounter)
            uint8 TimerCaptureCounter;
        #endif /* variable declarations for backing up non retention registers in CY_UDB_V1 */

        #if (!SpeedMsgTimer_UDB_CONTROL_REG_REMOVED)
            uint8 TimerControlRegister;
        #endif /* variable declaration for backing up enable state of the Timer */
    #endif /* define backup variables only for UDB implementation. Fixed function registers are all retention */

}SpeedMsgTimer_backupStruct;


/***************************************
*       Function Prototypes
***************************************/

void    SpeedMsgTimer_Start(void) ;
void    SpeedMsgTimer_Stop(void) ;

void    SpeedMsgTimer_SetInterruptMode(uint8 interruptMode) ;
uint8   SpeedMsgTimer_ReadStatusRegister(void) ;
/* Deprecated function. Do not use this in future. Retained for backward compatibility */
#define SpeedMsgTimer_GetInterruptSource() SpeedMsgTimer_ReadStatusRegister()

#if(!SpeedMsgTimer_UDB_CONTROL_REG_REMOVED)
    uint8   SpeedMsgTimer_ReadControlRegister(void) ;
    void    SpeedMsgTimer_WriteControlRegister(uint8 control) ;
#endif /* (!SpeedMsgTimer_UDB_CONTROL_REG_REMOVED) */

uint8  SpeedMsgTimer_ReadPeriod(void) ;
void    SpeedMsgTimer_WritePeriod(uint8 period) ;
uint8  SpeedMsgTimer_ReadCounter(void) ;
void    SpeedMsgTimer_WriteCounter(uint8 counter) ;
uint8  SpeedMsgTimer_ReadCapture(void) ;
void    SpeedMsgTimer_SoftwareCapture(void) ;

#if(!SpeedMsgTimer_UsingFixedFunction) /* UDB Prototypes */
    #if (SpeedMsgTimer_SoftwareCaptureMode)
        void    SpeedMsgTimer_SetCaptureMode(uint8 captureMode) ;
    #endif /* (!SpeedMsgTimer_UsingFixedFunction) */

    #if (SpeedMsgTimer_SoftwareTriggerMode)
        void    SpeedMsgTimer_SetTriggerMode(uint8 triggerMode) ;
    #endif /* (SpeedMsgTimer_SoftwareTriggerMode) */

    #if (SpeedMsgTimer_EnableTriggerMode)
        void    SpeedMsgTimer_EnableTrigger(void) ;
        void    SpeedMsgTimer_DisableTrigger(void) ;
    #endif /* (SpeedMsgTimer_EnableTriggerMode) */


    #if(SpeedMsgTimer_InterruptOnCaptureCount)
        void    SpeedMsgTimer_SetInterruptCount(uint8 interruptCount) ;
    #endif /* (SpeedMsgTimer_InterruptOnCaptureCount) */

    #if (SpeedMsgTimer_UsingHWCaptureCounter)
        void    SpeedMsgTimer_SetCaptureCount(uint8 captureCount) ;
        uint8   SpeedMsgTimer_ReadCaptureCount(void) ;
    #endif /* (SpeedMsgTimer_UsingHWCaptureCounter) */

    void SpeedMsgTimer_ClearFIFO(void) ;
#endif /* UDB Prototypes */

/* Sleep Retention APIs */
void SpeedMsgTimer_Init(void)          ;
void SpeedMsgTimer_Enable(void)        ;
void SpeedMsgTimer_SaveConfig(void)    ;
void SpeedMsgTimer_RestoreConfig(void) ;
void SpeedMsgTimer_Sleep(void)         ;
void SpeedMsgTimer_Wakeup(void)        ;


/***************************************
*   Enumerated Types and Parameters
***************************************/

/* Enumerated Type B_Timer__CaptureModes, Used in Capture Mode */
#define SpeedMsgTimer__B_TIMER__CM_NONE 0
#define SpeedMsgTimer__B_TIMER__CM_RISINGEDGE 1
#define SpeedMsgTimer__B_TIMER__CM_FALLINGEDGE 2
#define SpeedMsgTimer__B_TIMER__CM_EITHEREDGE 3
#define SpeedMsgTimer__B_TIMER__CM_SOFTWARE 4



/* Enumerated Type B_Timer__TriggerModes, Used in Trigger Mode */
#define SpeedMsgTimer__B_TIMER__TM_NONE 0x00u
#define SpeedMsgTimer__B_TIMER__TM_RISINGEDGE 0x04u
#define SpeedMsgTimer__B_TIMER__TM_FALLINGEDGE 0x08u
#define SpeedMsgTimer__B_TIMER__TM_EITHEREDGE 0x0Cu
#define SpeedMsgTimer__B_TIMER__TM_SOFTWARE 0x10u


/***************************************
*    Initialial Parameter Constants
***************************************/

#define SpeedMsgTimer_INIT_PERIOD             49u
#define SpeedMsgTimer_INIT_CAPTURE_MODE       ((uint8)((uint8)0u << SpeedMsgTimer_CTRL_CAP_MODE_SHIFT))
#define SpeedMsgTimer_INIT_TRIGGER_MODE       ((uint8)((uint8)0u << SpeedMsgTimer_CTRL_TRIG_MODE_SHIFT))
#if (SpeedMsgTimer_UsingFixedFunction)
    #define SpeedMsgTimer_INIT_INTERRUPT_MODE (((uint8)((uint8)1u << SpeedMsgTimer_STATUS_TC_INT_MASK_SHIFT)) | \
                                                  ((uint8)((uint8)0 << SpeedMsgTimer_STATUS_CAPTURE_INT_MASK_SHIFT)))
#else
    #define SpeedMsgTimer_INIT_INTERRUPT_MODE (((uint8)((uint8)1u << SpeedMsgTimer_STATUS_TC_INT_MASK_SHIFT)) | \
                                                 ((uint8)((uint8)0 << SpeedMsgTimer_STATUS_CAPTURE_INT_MASK_SHIFT)) | \
                                                 ((uint8)((uint8)0 << SpeedMsgTimer_STATUS_FIFOFULL_INT_MASK_SHIFT)))
#endif /* (SpeedMsgTimer_UsingFixedFunction) */
#define SpeedMsgTimer_INIT_CAPTURE_COUNT      (2u)
#define SpeedMsgTimer_INIT_INT_CAPTURE_COUNT  ((uint8)((uint8)(1u - 1u) << SpeedMsgTimer_CTRL_INTCNT_SHIFT))


/***************************************
*           Registers
***************************************/

#if (SpeedMsgTimer_UsingFixedFunction) /* Implementation Specific Registers and Register Constants */


    /***************************************
    *    Fixed Function Registers
    ***************************************/

    #define SpeedMsgTimer_STATUS         (*(reg8 *) SpeedMsgTimer_TimerHW__SR0 )
    /* In Fixed Function Block Status and Mask are the same register */
    #define SpeedMsgTimer_STATUS_MASK    (*(reg8 *) SpeedMsgTimer_TimerHW__SR0 )
    #define SpeedMsgTimer_CONTROL        (*(reg8 *) SpeedMsgTimer_TimerHW__CFG0)
    #define SpeedMsgTimer_CONTROL2       (*(reg8 *) SpeedMsgTimer_TimerHW__CFG1)
    #define SpeedMsgTimer_CONTROL2_PTR   ( (reg8 *) SpeedMsgTimer_TimerHW__CFG1)
    #define SpeedMsgTimer_RT1            (*(reg8 *) SpeedMsgTimer_TimerHW__RT1)
    #define SpeedMsgTimer_RT1_PTR        ( (reg8 *) SpeedMsgTimer_TimerHW__RT1)

    #if (CY_PSOC3 || CY_PSOC5LP)
        #define SpeedMsgTimer_CONTROL3       (*(reg8 *) SpeedMsgTimer_TimerHW__CFG2)
        #define SpeedMsgTimer_CONTROL3_PTR   ( (reg8 *) SpeedMsgTimer_TimerHW__CFG2)
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */
    #define SpeedMsgTimer_GLOBAL_ENABLE  (*(reg8 *) SpeedMsgTimer_TimerHW__PM_ACT_CFG)
    #define SpeedMsgTimer_GLOBAL_STBY_ENABLE  (*(reg8 *) SpeedMsgTimer_TimerHW__PM_STBY_CFG)

    #define SpeedMsgTimer_CAPTURE_LSB         (* (reg16 *) SpeedMsgTimer_TimerHW__CAP0 )
    #define SpeedMsgTimer_CAPTURE_LSB_PTR       ((reg16 *) SpeedMsgTimer_TimerHW__CAP0 )
    #define SpeedMsgTimer_PERIOD_LSB          (* (reg16 *) SpeedMsgTimer_TimerHW__PER0 )
    #define SpeedMsgTimer_PERIOD_LSB_PTR        ((reg16 *) SpeedMsgTimer_TimerHW__PER0 )
    #define SpeedMsgTimer_COUNTER_LSB         (* (reg16 *) SpeedMsgTimer_TimerHW__CNT_CMP0 )
    #define SpeedMsgTimer_COUNTER_LSB_PTR       ((reg16 *) SpeedMsgTimer_TimerHW__CNT_CMP0 )


    /***************************************
    *    Register Constants
    ***************************************/

    /* Fixed Function Block Chosen */
    #define SpeedMsgTimer_BLOCK_EN_MASK                     SpeedMsgTimer_TimerHW__PM_ACT_MSK
    #define SpeedMsgTimer_BLOCK_STBY_EN_MASK                SpeedMsgTimer_TimerHW__PM_STBY_MSK

    /* Control Register Bit Locations */
    /* Interrupt Count - Not valid for Fixed Function Block */
    #define SpeedMsgTimer_CTRL_INTCNT_SHIFT                  0x00u
    /* Trigger Polarity - Not valid for Fixed Function Block */
    #define SpeedMsgTimer_CTRL_TRIG_MODE_SHIFT               0x00u
    /* Trigger Enable - Not valid for Fixed Function Block */
    #define SpeedMsgTimer_CTRL_TRIG_EN_SHIFT                 0x00u
    /* Capture Polarity - Not valid for Fixed Function Block */
    #define SpeedMsgTimer_CTRL_CAP_MODE_SHIFT                0x00u
    /* Timer Enable - As defined in Register Map, part of TMRX_CFG0 register */
    #define SpeedMsgTimer_CTRL_ENABLE_SHIFT                  0x00u

    /* Control Register Bit Masks */
    #define SpeedMsgTimer_CTRL_ENABLE                        ((uint8)((uint8)0x01u << SpeedMsgTimer_CTRL_ENABLE_SHIFT))

    /* Control2 Register Bit Masks */
    /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define SpeedMsgTimer_CTRL2_IRQ_SEL_SHIFT                 0x00u
    #define SpeedMsgTimer_CTRL2_IRQ_SEL                      ((uint8)((uint8)0x01u << SpeedMsgTimer_CTRL2_IRQ_SEL_SHIFT))

    #if (CY_PSOC5A)
        /* Use CFG1 Mode bits to set run mode */
        /* As defined by Verilog Implementation */
        #define SpeedMsgTimer_CTRL_MODE_SHIFT                 0x01u
        #define SpeedMsgTimer_CTRL_MODE_MASK                 ((uint8)((uint8)0x07u << SpeedMsgTimer_CTRL_MODE_SHIFT))
    #endif /* (CY_PSOC5A) */
    #if (CY_PSOC3 || CY_PSOC5LP)
        /* Control3 Register Bit Locations */
        #define SpeedMsgTimer_CTRL_RCOD_SHIFT        0x02u
        #define SpeedMsgTimer_CTRL_ENBL_SHIFT        0x00u
        #define SpeedMsgTimer_CTRL_MODE_SHIFT        0x00u

        /* Control3 Register Bit Masks */
        #define SpeedMsgTimer_CTRL_RCOD_MASK  ((uint8)((uint8)0x03u << SpeedMsgTimer_CTRL_RCOD_SHIFT)) /* ROD and COD bit masks */
        #define SpeedMsgTimer_CTRL_ENBL_MASK  ((uint8)((uint8)0x80u << SpeedMsgTimer_CTRL_ENBL_SHIFT)) /* HW_EN bit mask */
        #define SpeedMsgTimer_CTRL_MODE_MASK  ((uint8)((uint8)0x03u << SpeedMsgTimer_CTRL_MODE_SHIFT)) /* Run mode bit mask */

        #define SpeedMsgTimer_CTRL_RCOD       ((uint8)((uint8)0x03u << SpeedMsgTimer_CTRL_RCOD_SHIFT))
        #define SpeedMsgTimer_CTRL_ENBL       ((uint8)((uint8)0x80u << SpeedMsgTimer_CTRL_ENBL_SHIFT))
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */

    /*RT1 Synch Constants: Applicable for PSoC3 and PSoC5LP */
    #define SpeedMsgTimer_RT1_SHIFT                       0x04u
    /* Sync TC and CMP bit masks */
    #define SpeedMsgTimer_RT1_MASK                        ((uint8)((uint8)0x03u << SpeedMsgTimer_RT1_SHIFT))
    #define SpeedMsgTimer_SYNC                            ((uint8)((uint8)0x03u << SpeedMsgTimer_RT1_SHIFT))
    #define SpeedMsgTimer_SYNCDSI_SHIFT                   0x00u
    /* Sync all DSI inputs with Mask  */
    #define SpeedMsgTimer_SYNCDSI_MASK                    ((uint8)((uint8)0x0Fu << SpeedMsgTimer_SYNCDSI_SHIFT))
    /* Sync all DSI inputs */
    #define SpeedMsgTimer_SYNCDSI_EN                      ((uint8)((uint8)0x0Fu << SpeedMsgTimer_SYNCDSI_SHIFT))

    #define SpeedMsgTimer_CTRL_MODE_PULSEWIDTH            ((uint8)((uint8)0x01u << SpeedMsgTimer_CTRL_MODE_SHIFT))
    #define SpeedMsgTimer_CTRL_MODE_PERIOD                ((uint8)((uint8)0x02u << SpeedMsgTimer_CTRL_MODE_SHIFT))
    #define SpeedMsgTimer_CTRL_MODE_CONTINUOUS            ((uint8)((uint8)0x00u << SpeedMsgTimer_CTRL_MODE_SHIFT))

    /* Status Register Bit Locations */
    /* As defined in Register Map, part of TMRX_SR0 register */
    #define SpeedMsgTimer_STATUS_TC_SHIFT                 0x07u
    /* As defined in Register Map, part of TMRX_SR0 register, Shared with Compare Status */
    #define SpeedMsgTimer_STATUS_CAPTURE_SHIFT            0x06u
    /* As defined in Register Map, part of TMRX_SR0 register */
    #define SpeedMsgTimer_STATUS_TC_INT_MASK_SHIFT        (SpeedMsgTimer_STATUS_TC_SHIFT - 0x04u)
    /* As defined in Register Map, part of TMRX_SR0 register, Shared with Compare Status */
    #define SpeedMsgTimer_STATUS_CAPTURE_INT_MASK_SHIFT   (SpeedMsgTimer_STATUS_CAPTURE_SHIFT - 0x04u)

    /* Status Register Bit Masks */
    #define SpeedMsgTimer_STATUS_TC                       ((uint8)((uint8)0x01u << SpeedMsgTimer_STATUS_TC_SHIFT))
    #define SpeedMsgTimer_STATUS_CAPTURE                  ((uint8)((uint8)0x01u << SpeedMsgTimer_STATUS_CAPTURE_SHIFT))
    /* Interrupt Enable Bit-Mask for interrupt on TC */
    #define SpeedMsgTimer_STATUS_TC_INT_MASK              ((uint8)((uint8)0x01u << SpeedMsgTimer_STATUS_TC_INT_MASK_SHIFT))
    /* Interrupt Enable Bit-Mask for interrupt on Capture */
    #define SpeedMsgTimer_STATUS_CAPTURE_INT_MASK         ((uint8)((uint8)0x01u << SpeedMsgTimer_STATUS_CAPTURE_INT_MASK_SHIFT))

#else   /* UDB Registers and Register Constants */


    /***************************************
    *           UDB Registers
    ***************************************/

    #define SpeedMsgTimer_STATUS              (* (reg8 *) SpeedMsgTimer_TimerUDB_rstSts_stsreg__STATUS_REG )
    #define SpeedMsgTimer_STATUS_MASK         (* (reg8 *) SpeedMsgTimer_TimerUDB_rstSts_stsreg__MASK_REG)
    #define SpeedMsgTimer_STATUS_AUX_CTRL     (* (reg8 *) SpeedMsgTimer_TimerUDB_rstSts_stsreg__STATUS_AUX_CTL_REG)
    #define SpeedMsgTimer_CONTROL             (* (reg8 *) SpeedMsgTimer_TimerUDB_sCTRLReg_SyncCtl_ctrlreg__CONTROL_REG )
    
    #if(SpeedMsgTimer_Resolution <= 8u) /* 8-bit Timer */
        #define SpeedMsgTimer_CAPTURE_LSB         (* (reg8 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__F0_REG )
        #define SpeedMsgTimer_CAPTURE_LSB_PTR       ((reg8 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__F0_REG )
        #define SpeedMsgTimer_PERIOD_LSB          (* (reg8 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__D0_REG )
        #define SpeedMsgTimer_PERIOD_LSB_PTR        ((reg8 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__D0_REG )
        #define SpeedMsgTimer_COUNTER_LSB         (* (reg8 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__A0_REG )
        #define SpeedMsgTimer_COUNTER_LSB_PTR       ((reg8 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__A0_REG )
    #elif(SpeedMsgTimer_Resolution <= 16u) /* 8-bit Timer */
        #if(CY_PSOC3) /* 8-bit addres space */
            #define SpeedMsgTimer_CAPTURE_LSB         (* (reg16 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__F0_REG )
            #define SpeedMsgTimer_CAPTURE_LSB_PTR       ((reg16 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__F0_REG )
            #define SpeedMsgTimer_PERIOD_LSB          (* (reg16 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__D0_REG )
            #define SpeedMsgTimer_PERIOD_LSB_PTR        ((reg16 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__D0_REG )
            #define SpeedMsgTimer_COUNTER_LSB         (* (reg16 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__A0_REG )
            #define SpeedMsgTimer_COUNTER_LSB_PTR       ((reg16 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__A0_REG )
        #else /* 16-bit address space */
            #define SpeedMsgTimer_CAPTURE_LSB         (* (reg16 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__16BIT_F0_REG )
            #define SpeedMsgTimer_CAPTURE_LSB_PTR       ((reg16 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__16BIT_F0_REG )
            #define SpeedMsgTimer_PERIOD_LSB          (* (reg16 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__16BIT_D0_REG )
            #define SpeedMsgTimer_PERIOD_LSB_PTR        ((reg16 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__16BIT_D0_REG )
            #define SpeedMsgTimer_COUNTER_LSB         (* (reg16 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__16BIT_A0_REG )
            #define SpeedMsgTimer_COUNTER_LSB_PTR       ((reg16 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__16BIT_A0_REG )
        #endif /* CY_PSOC3 */
    #elif(SpeedMsgTimer_Resolution <= 24u)/* 24-bit Timer */
        #define SpeedMsgTimer_CAPTURE_LSB         (* (reg32 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__F0_REG )
        #define SpeedMsgTimer_CAPTURE_LSB_PTR       ((reg32 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__F0_REG )
        #define SpeedMsgTimer_PERIOD_LSB          (* (reg32 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__D0_REG )
        #define SpeedMsgTimer_PERIOD_LSB_PTR        ((reg32 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__D0_REG )
        #define SpeedMsgTimer_COUNTER_LSB         (* (reg32 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__A0_REG )
        #define SpeedMsgTimer_COUNTER_LSB_PTR       ((reg32 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__A0_REG )
    #else /* 32-bit Timer */
        #if(CY_PSOC3 || CY_PSOC5) /* 8-bit address space */
            #define SpeedMsgTimer_CAPTURE_LSB         (* (reg32 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__F0_REG )
            #define SpeedMsgTimer_CAPTURE_LSB_PTR       ((reg32 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__F0_REG )
            #define SpeedMsgTimer_PERIOD_LSB          (* (reg32 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__D0_REG )
            #define SpeedMsgTimer_PERIOD_LSB_PTR        ((reg32 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__D0_REG )
            #define SpeedMsgTimer_COUNTER_LSB         (* (reg32 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__A0_REG )
            #define SpeedMsgTimer_COUNTER_LSB_PTR       ((reg32 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__A0_REG )
        #else /* 32-bit address space */
            #define SpeedMsgTimer_CAPTURE_LSB         (* (reg32 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__32BIT_F0_REG )
            #define SpeedMsgTimer_CAPTURE_LSB_PTR       ((reg32 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__32BIT_F0_REG )
            #define SpeedMsgTimer_PERIOD_LSB          (* (reg32 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__32BIT_D0_REG )
            #define SpeedMsgTimer_PERIOD_LSB_PTR        ((reg32 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__32BIT_D0_REG )
            #define SpeedMsgTimer_COUNTER_LSB         (* (reg32 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__32BIT_A0_REG )
            #define SpeedMsgTimer_COUNTER_LSB_PTR       ((reg32 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__32BIT_A0_REG )
        #endif /* CY_PSOC3 || CY_PSOC5 */ 
    #endif

    #define SpeedMsgTimer_COUNTER_LSB_PTR_8BIT       ((reg8 *) SpeedMsgTimer_TimerUDB_sT8_timerdp_u0__A0_REG )
    
    #if (SpeedMsgTimer_UsingHWCaptureCounter)
        #define SpeedMsgTimer_CAP_COUNT              (*(reg8 *) SpeedMsgTimer_TimerUDB_sCapCount_counter__PERIOD_REG )
        #define SpeedMsgTimer_CAP_COUNT_PTR          ( (reg8 *) SpeedMsgTimer_TimerUDB_sCapCount_counter__PERIOD_REG )
        #define SpeedMsgTimer_CAPTURE_COUNT_CTRL     (*(reg8 *) SpeedMsgTimer_TimerUDB_sCapCount_counter__CONTROL_AUX_CTL_REG )
        #define SpeedMsgTimer_CAPTURE_COUNT_CTRL_PTR ( (reg8 *) SpeedMsgTimer_TimerUDB_sCapCount_counter__CONTROL_AUX_CTL_REG )
    #endif /* (SpeedMsgTimer_UsingHWCaptureCounter) */


    /***************************************
    *       Register Constants
    ***************************************/

    /* Control Register Bit Locations */
    #define SpeedMsgTimer_CTRL_INTCNT_SHIFT              0x00u       /* As defined by Verilog Implementation */
    #define SpeedMsgTimer_CTRL_TRIG_MODE_SHIFT           0x02u       /* As defined by Verilog Implementation */
    #define SpeedMsgTimer_CTRL_TRIG_EN_SHIFT             0x04u       /* As defined by Verilog Implementation */
    #define SpeedMsgTimer_CTRL_CAP_MODE_SHIFT            0x05u       /* As defined by Verilog Implementation */
    #define SpeedMsgTimer_CTRL_ENABLE_SHIFT              0x07u       /* As defined by Verilog Implementation */

    /* Control Register Bit Masks */
    #define SpeedMsgTimer_CTRL_INTCNT_MASK               ((uint8)((uint8)0x03u << SpeedMsgTimer_CTRL_INTCNT_SHIFT))
    #define SpeedMsgTimer_CTRL_TRIG_MODE_MASK            ((uint8)((uint8)0x03u << SpeedMsgTimer_CTRL_TRIG_MODE_SHIFT))
    #define SpeedMsgTimer_CTRL_TRIG_EN                   ((uint8)((uint8)0x01u << SpeedMsgTimer_CTRL_TRIG_EN_SHIFT))
    #define SpeedMsgTimer_CTRL_CAP_MODE_MASK             ((uint8)((uint8)0x03u << SpeedMsgTimer_CTRL_CAP_MODE_SHIFT))
    #define SpeedMsgTimer_CTRL_ENABLE                    ((uint8)((uint8)0x01u << SpeedMsgTimer_CTRL_ENABLE_SHIFT))

    /* Bit Counter (7-bit) Control Register Bit Definitions */
    /* As defined by the Register map for the AUX Control Register */
    #define SpeedMsgTimer_CNTR_ENABLE                    0x20u

    /* Status Register Bit Locations */
    #define SpeedMsgTimer_STATUS_TC_SHIFT                0x00u  /* As defined by Verilog Implementation */
    #define SpeedMsgTimer_STATUS_CAPTURE_SHIFT           0x01u  /* As defined by Verilog Implementation */
    #define SpeedMsgTimer_STATUS_TC_INT_MASK_SHIFT       SpeedMsgTimer_STATUS_TC_SHIFT
    #define SpeedMsgTimer_STATUS_CAPTURE_INT_MASK_SHIFT  SpeedMsgTimer_STATUS_CAPTURE_SHIFT
    #define SpeedMsgTimer_STATUS_FIFOFULL_SHIFT          0x02u  /* As defined by Verilog Implementation */
    #define SpeedMsgTimer_STATUS_FIFONEMP_SHIFT          0x03u  /* As defined by Verilog Implementation */
    #define SpeedMsgTimer_STATUS_FIFOFULL_INT_MASK_SHIFT SpeedMsgTimer_STATUS_FIFOFULL_SHIFT

    /* Status Register Bit Masks */
    /* Sticky TC Event Bit-Mask */
    #define SpeedMsgTimer_STATUS_TC                      ((uint8)((uint8)0x01u << SpeedMsgTimer_STATUS_TC_SHIFT))
    /* Sticky Capture Event Bit-Mask */
    #define SpeedMsgTimer_STATUS_CAPTURE                 ((uint8)((uint8)0x01u << SpeedMsgTimer_STATUS_CAPTURE_SHIFT))
    /* Interrupt Enable Bit-Mask */
    #define SpeedMsgTimer_STATUS_TC_INT_MASK             ((uint8)((uint8)0x01u << SpeedMsgTimer_STATUS_TC_SHIFT))
    /* Interrupt Enable Bit-Mask */
    #define SpeedMsgTimer_STATUS_CAPTURE_INT_MASK        ((uint8)((uint8)0x01u << SpeedMsgTimer_STATUS_CAPTURE_SHIFT))
    /* NOT-Sticky FIFO Full Bit-Mask */
    #define SpeedMsgTimer_STATUS_FIFOFULL                ((uint8)((uint8)0x01u << SpeedMsgTimer_STATUS_FIFOFULL_SHIFT))
    /* NOT-Sticky FIFO Not Empty Bit-Mask */
    #define SpeedMsgTimer_STATUS_FIFONEMP                ((uint8)((uint8)0x01u << SpeedMsgTimer_STATUS_FIFONEMP_SHIFT))
    /* Interrupt Enable Bit-Mask */
    #define SpeedMsgTimer_STATUS_FIFOFULL_INT_MASK       ((uint8)((uint8)0x01u << SpeedMsgTimer_STATUS_FIFOFULL_SHIFT))

    #define SpeedMsgTimer_STATUS_ACTL_INT_EN             0x10u   /* As defined for the ACTL Register */

    /* Datapath Auxillary Control Register definitions */
    #define SpeedMsgTimer_AUX_CTRL_FIFO0_CLR             0x01u   /* As defined by Register map */
    #define SpeedMsgTimer_AUX_CTRL_FIFO1_CLR             0x02u   /* As defined by Register map */
    #define SpeedMsgTimer_AUX_CTRL_FIFO0_LVL             0x04u   /* As defined by Register map */
    #define SpeedMsgTimer_AUX_CTRL_FIFO1_LVL             0x08u   /* As defined by Register map */
    #define SpeedMsgTimer_STATUS_ACTL_INT_EN_MASK        0x10u   /* As defined for the ACTL Register */

#endif /* Implementation Specific Registers and Register Constants */

#endif  /* CY_Timer_v2_30_SpeedMsgTimer_H */


/* [] END OF FILE */
