/*******************************************************************************
* File Name: TestCounter.h  
* Version 3.0
*
*  Description:
*   Contains the function prototypes and constants available to the counter
*   user module.
*
*   Note:
*    None
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/
    
#if !defined(CY_COUNTER_TestCounter_H)
#define CY_COUNTER_TestCounter_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

extern uint8 TestCounter_initVar;

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component Counter_v3_0 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */

/* Error message for removed TestCounter_CounterUDB_sCTRLReg_ctrlreg through optimization */
#ifdef TestCounter_CounterUDB_sCTRLReg_ctrlreg__REMOVED
    #error Counter_v3_0 detected with a constant 0 for the enable, a \
                                constant 0 for the count or constant 1 for \
                                the reset. This will prevent the component from\
                                operating.
#endif /* TestCounter_CounterUDB_sCTRLReg_ctrlreg__REMOVED */


/**************************************
*           Parameter Defaults        
**************************************/

#define TestCounter_Resolution            16u
#define TestCounter_UsingFixedFunction    1u
#define TestCounter_ControlRegRemoved     0u
#define TestCounter_COMPARE_MODE_SOFTWARE 0u
#define TestCounter_CAPTURE_MODE_SOFTWARE 0u
#define TestCounter_RunModeUsed           0u


/***************************************
*       Type defines
***************************************/


/**************************************************************************
 * Sleep Mode API Support
 * Backup structure for Sleep Wake up operations
 *************************************************************************/
typedef struct
{
    uint8 CounterEnableState; 
    uint16 CounterUdb;         /* Current Counter Value */

    #if (!TestCounter_ControlRegRemoved)
        uint8 CounterControlRegister;               /* Counter Control Register */
    #endif /* (!TestCounter_ControlRegRemoved) */

}TestCounter_backupStruct;


/**************************************
 *  Function Prototypes
 *************************************/
void    TestCounter_Start(void) ;
void    TestCounter_Stop(void) ;
void    TestCounter_SetInterruptMode(uint8 interruptsMask) ;
uint8   TestCounter_ReadStatusRegister(void) ;
#define TestCounter_GetInterruptSource() TestCounter_ReadStatusRegister()
#if(!TestCounter_ControlRegRemoved)
    uint8   TestCounter_ReadControlRegister(void) ;
    void    TestCounter_WriteControlRegister(uint8 control) \
        ;
#endif /* (!TestCounter_ControlRegRemoved) */
#if (!(TestCounter_UsingFixedFunction && (CY_PSOC5A)))
    void    TestCounter_WriteCounter(uint16 counter) \
            ; 
#endif /* (!(TestCounter_UsingFixedFunction && (CY_PSOC5A))) */
uint16  TestCounter_ReadCounter(void) ;
uint16  TestCounter_ReadCapture(void) ;
void    TestCounter_WritePeriod(uint16 period) \
    ;
uint16  TestCounter_ReadPeriod( void ) ;
#if (!TestCounter_UsingFixedFunction)
    void    TestCounter_WriteCompare(uint16 compare) \
        ;
    uint16  TestCounter_ReadCompare( void ) \
        ;
#endif /* (!TestCounter_UsingFixedFunction) */

#if (TestCounter_COMPARE_MODE_SOFTWARE)
    void    TestCounter_SetCompareMode(uint8 compareMode) ;
#endif /* (TestCounter_COMPARE_MODE_SOFTWARE) */
#if (TestCounter_CAPTURE_MODE_SOFTWARE)
    void    TestCounter_SetCaptureMode(uint8 captureMode) ;
#endif /* (TestCounter_CAPTURE_MODE_SOFTWARE) */
void TestCounter_ClearFIFO(void)     ;
void TestCounter_Init(void)          ;
void TestCounter_Enable(void)        ;
void TestCounter_SaveConfig(void)    ;
void TestCounter_RestoreConfig(void) ;
void TestCounter_Sleep(void)         ;
void TestCounter_Wakeup(void)        ;


/***************************************
*   Enumerated Types and Parameters
***************************************/

/* Enumerated Type B_Counter__CompareModes, Used in Compare Mode retained for backward compatibility of tests*/
#define TestCounter__B_COUNTER__LESS_THAN 1
#define TestCounter__B_COUNTER__LESS_THAN_OR_EQUAL 2
#define TestCounter__B_COUNTER__EQUAL 0
#define TestCounter__B_COUNTER__GREATER_THAN 3
#define TestCounter__B_COUNTER__GREATER_THAN_OR_EQUAL 4
#define TestCounter__B_COUNTER__SOFTWARE 5

/* Enumerated Type Counter_CompareModes */
#define TestCounter_CMP_MODE_LT 1u
#define TestCounter_CMP_MODE_LTE 2u
#define TestCounter_CMP_MODE_EQ 0u
#define TestCounter_CMP_MODE_GT 3u
#define TestCounter_CMP_MODE_GTE 4u
#define TestCounter_CMP_MODE_SOFTWARE_CONTROLLED 5u

/* Enumerated Type B_Counter__CaptureModes, Used in Capture Mode retained for backward compatibility of tests*/
#define TestCounter__B_COUNTER__NONE 0
#define TestCounter__B_COUNTER__RISING_EDGE 1
#define TestCounter__B_COUNTER__FALLING_EDGE 2
#define TestCounter__B_COUNTER__EITHER_EDGE 3
#define TestCounter__B_COUNTER__SOFTWARE_CONTROL 4

/* Enumerated Type Counter_CompareModes */
#define TestCounter_CAP_MODE_NONE 0u
#define TestCounter_CAP_MODE_RISE 1u
#define TestCounter_CAP_MODE_FALL 2u
#define TestCounter_CAP_MODE_BOTH 3u
#define TestCounter_CAP_MODE_SOFTWARE_CONTROLLED 4u


/***************************************
 *  Initialization Values
 **************************************/
#define TestCounter_CAPTURE_MODE_CONF       0u
#define TestCounter_INIT_PERIOD_VALUE       65535u
#define TestCounter_INIT_COUNTER_VALUE      0u
#if (TestCounter_UsingFixedFunction)
#define TestCounter_INIT_INTERRUPTS_MASK    ((uint8)((uint8)0u << TestCounter_STATUS_ZERO_INT_EN_MASK_SHIFT))
#else
#define TestCounter_INIT_COMPARE_VALUE      128u
#define TestCounter_INIT_INTERRUPTS_MASK ((uint8)((uint8)0u << TestCounter_STATUS_ZERO_INT_EN_MASK_SHIFT) | \
        ((uint8)((uint8)0u << TestCounter_STATUS_CAPTURE_INT_EN_MASK_SHIFT)) | \
        ((uint8)((uint8)0u << TestCounter_STATUS_CMP_INT_EN_MASK_SHIFT)) | \
        ((uint8)((uint8)0u << TestCounter_STATUS_OVERFLOW_INT_EN_MASK_SHIFT)) | \
        ((uint8)((uint8)0u << TestCounter_STATUS_UNDERFLOW_INT_EN_MASK_SHIFT)))
#define TestCounter_DEFAULT_COMPARE_MODE    1u

#if( 0 != TestCounter_CAPTURE_MODE_CONF)
    #define TestCounter_DEFAULT_CAPTURE_MODE    ((uint8)((uint8)0u << TestCounter_CTRL_CAPMODE0_SHIFT))
#else    
    #define TestCounter_DEFAULT_CAPTURE_MODE    (0u )
#endif /* ( 0 != TestCounter_CAPTURE_MODE_CONF) */

#endif /* (TestCounter_UsingFixedFunction) */


/**************************************
 *  Registers
 *************************************/
#if (TestCounter_UsingFixedFunction)
    #define TestCounter_STATICCOUNT_LSB     (*(reg16 *) TestCounter_CounterHW__CAP0 )
    #define TestCounter_STATICCOUNT_LSB_PTR ( (reg16 *) TestCounter_CounterHW__CAP0 )
    #define TestCounter_PERIOD_LSB          (*(reg16 *) TestCounter_CounterHW__PER0 )
    #define TestCounter_PERIOD_LSB_PTR      ( (reg16 *) TestCounter_CounterHW__PER0 )
    /* MODE must be set to 1 to set the compare value */
    #define TestCounter_COMPARE_LSB         (*(reg16 *) TestCounter_CounterHW__CNT_CMP0 )
    #define TestCounter_COMPARE_LSB_PTR     ( (reg16 *) TestCounter_CounterHW__CNT_CMP0 )
    /* MODE must be set to 0 to get the count */
    #define TestCounter_COUNTER_LSB         (*(reg16 *) TestCounter_CounterHW__CNT_CMP0 )
    #define TestCounter_COUNTER_LSB_PTR     ( (reg16 *) TestCounter_CounterHW__CNT_CMP0 )
    #define TestCounter_RT1                 (*(reg8 *) TestCounter_CounterHW__RT1)
    #define TestCounter_RT1_PTR             ( (reg8 *) TestCounter_CounterHW__RT1)
#else
    
    #if (TestCounter_Resolution <= 8u) /* 8-bit Counter */
    
        #define TestCounter_STATICCOUNT_LSB     (*(reg8 *) \
            TestCounter_CounterUDB_sC16_counterdp_u0__F0_REG )
        #define TestCounter_STATICCOUNT_LSB_PTR ( (reg8 *) \
            TestCounter_CounterUDB_sC16_counterdp_u0__F0_REG )
        #define TestCounter_PERIOD_LSB          (*(reg8 *) \
            TestCounter_CounterUDB_sC16_counterdp_u0__D0_REG )
        #define TestCounter_PERIOD_LSB_PTR      ( (reg8 *) \
            TestCounter_CounterUDB_sC16_counterdp_u0__D0_REG )
        #define TestCounter_COMPARE_LSB         (*(reg8 *) \
            TestCounter_CounterUDB_sC16_counterdp_u0__D1_REG )
        #define TestCounter_COMPARE_LSB_PTR     ( (reg8 *) \
            TestCounter_CounterUDB_sC16_counterdp_u0__D1_REG )
        #define TestCounter_COUNTER_LSB         (*(reg8 *) \
            TestCounter_CounterUDB_sC16_counterdp_u0__A0_REG )  
        #define TestCounter_COUNTER_LSB_PTR     ( (reg8 *)\
            TestCounter_CounterUDB_sC16_counterdp_u0__A0_REG )
    
    #elif(TestCounter_Resolution <= 16u) /* 16-bit Counter */
        #if(CY_PSOC3) /* 8-bit address space */ 
            #define TestCounter_STATICCOUNT_LSB     (*(reg16 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__F0_REG )
            #define TestCounter_STATICCOUNT_LSB_PTR ( (reg16 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__F0_REG )
            #define TestCounter_PERIOD_LSB          (*(reg16 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__D0_REG )
            #define TestCounter_PERIOD_LSB_PTR      ( (reg16 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__D0_REG )
            #define TestCounter_COMPARE_LSB         (*(reg16 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__D1_REG )
            #define TestCounter_COMPARE_LSB_PTR     ( (reg16 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__D1_REG )
            #define TestCounter_COUNTER_LSB         (*(reg16 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__A0_REG )  
            #define TestCounter_COUNTER_LSB_PTR     ( (reg16 *)\
                TestCounter_CounterUDB_sC16_counterdp_u0__A0_REG )
        #else /* 16-bit address space */
            #define TestCounter_STATICCOUNT_LSB     (*(reg16 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__16BIT_F0_REG )
            #define TestCounter_STATICCOUNT_LSB_PTR ( (reg16 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__16BIT_F0_REG )
            #define TestCounter_PERIOD_LSB          (*(reg16 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__16BIT_D0_REG )
            #define TestCounter_PERIOD_LSB_PTR      ( (reg16 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__16BIT_D0_REG )
            #define TestCounter_COMPARE_LSB         (*(reg16 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__16BIT_D1_REG )
            #define TestCounter_COMPARE_LSB_PTR     ( (reg16 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__16BIT_D1_REG )
            #define TestCounter_COUNTER_LSB         (*(reg16 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__16BIT_A0_REG )  
            #define TestCounter_COUNTER_LSB_PTR     ( (reg16 *)\
                TestCounter_CounterUDB_sC16_counterdp_u0__16BIT_A0_REG )
        #endif /* CY_PSOC3 */   
    #elif(TestCounter_Resolution <= 24u) /* 24-bit Counter */
        
        #define TestCounter_STATICCOUNT_LSB     (*(reg32 *) \
            TestCounter_CounterUDB_sC16_counterdp_u0__F0_REG )
        #define TestCounter_STATICCOUNT_LSB_PTR ( (reg32 *) \
            TestCounter_CounterUDB_sC16_counterdp_u0__F0_REG )
        #define TestCounter_PERIOD_LSB          (*(reg32 *) \
            TestCounter_CounterUDB_sC16_counterdp_u0__D0_REG )
        #define TestCounter_PERIOD_LSB_PTR      ( (reg32 *) \
            TestCounter_CounterUDB_sC16_counterdp_u0__D0_REG )
        #define TestCounter_COMPARE_LSB         (*(reg32 *) \
            TestCounter_CounterUDB_sC16_counterdp_u0__D1_REG )
        #define TestCounter_COMPARE_LSB_PTR     ( (reg32 *) \
            TestCounter_CounterUDB_sC16_counterdp_u0__D1_REG )
        #define TestCounter_COUNTER_LSB         (*(reg32 *) \
            TestCounter_CounterUDB_sC16_counterdp_u0__A0_REG )  
        #define TestCounter_COUNTER_LSB_PTR     ( (reg32 *)\
            TestCounter_CounterUDB_sC16_counterdp_u0__A0_REG )
    
    #else /* 32-bit Counter */
        #if(CY_PSOC3 || CY_PSOC5) /* 8-bit address space */
            #define TestCounter_STATICCOUNT_LSB     (*(reg32 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__F0_REG )
            #define TestCounter_STATICCOUNT_LSB_PTR ( (reg32 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__F0_REG )
            #define TestCounter_PERIOD_LSB          (*(reg32 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__D0_REG )
            #define TestCounter_PERIOD_LSB_PTR      ( (reg32 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__D0_REG )
            #define TestCounter_COMPARE_LSB         (*(reg32 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__D1_REG )
            #define TestCounter_COMPARE_LSB_PTR     ( (reg32 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__D1_REG )
            #define TestCounter_COUNTER_LSB         (*(reg32 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__A0_REG )  
            #define TestCounter_COUNTER_LSB_PTR     ( (reg32 *)\
                TestCounter_CounterUDB_sC16_counterdp_u0__A0_REG )
        #else /* 32-bit address space */
            #define TestCounter_STATICCOUNT_LSB     (*(reg32 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__32BIT_F0_REG )
            #define TestCounter_STATICCOUNT_LSB_PTR ( (reg32 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__32BIT_F0_REG )
            #define TestCounter_PERIOD_LSB          (*(reg32 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__32BIT_D0_REG )
            #define TestCounter_PERIOD_LSB_PTR      ( (reg32 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__32BIT_D0_REG )
            #define TestCounter_COMPARE_LSB         (*(reg32 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__32BIT_D1_REG )
            #define TestCounter_COMPARE_LSB_PTR     ( (reg32 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__32BIT_D1_REG )
            #define TestCounter_COUNTER_LSB         (*(reg32 *) \
                TestCounter_CounterUDB_sC16_counterdp_u0__32BIT_A0_REG )  
            #define TestCounter_COUNTER_LSB_PTR     ( (reg32 *)\
                TestCounter_CounterUDB_sC16_counterdp_u0__32BIT_A0_REG )
        #endif /* CY_PSOC3 || CY_PSOC5 */   
    #endif

	#define TestCounter_COUNTER_LSB_PTR_8BIT     ( (reg8 *)\
                TestCounter_CounterUDB_sC16_counterdp_u0__A0_REG )
				
    #define TestCounter_AUX_CONTROLDP0 \
        (*(reg8 *) TestCounter_CounterUDB_sC16_counterdp_u0__DP_AUX_CTL_REG)
    
    #define TestCounter_AUX_CONTROLDP0_PTR \
        ( (reg8 *) TestCounter_CounterUDB_sC16_counterdp_u0__DP_AUX_CTL_REG)
    
    #if (TestCounter_Resolution == 16 || TestCounter_Resolution == 24 || TestCounter_Resolution == 32)
       #define TestCounter_AUX_CONTROLDP1 \
           (*(reg8 *) TestCounter_CounterUDB_sC16_counterdp_u1__DP_AUX_CTL_REG)
       #define TestCounter_AUX_CONTROLDP1_PTR \
           ( (reg8 *) TestCounter_CounterUDB_sC16_counterdp_u1__DP_AUX_CTL_REG)
    #endif /* (TestCounter_Resolution == 16 || TestCounter_Resolution == 24 || TestCounter_Resolution == 32) */
    
    #if (TestCounter_Resolution == 24 || TestCounter_Resolution == 32)
       #define TestCounter_AUX_CONTROLDP2 \
           (*(reg8 *) TestCounter_CounterUDB_sC16_counterdp_u2__DP_AUX_CTL_REG)
       #define TestCounter_AUX_CONTROLDP2_PTR \
           ( (reg8 *) TestCounter_CounterUDB_sC16_counterdp_u2__DP_AUX_CTL_REG)
    #endif /* (TestCounter_Resolution == 24 || TestCounter_Resolution == 32) */
    
    #if (TestCounter_Resolution == 32)
       #define TestCounter_AUX_CONTROLDP3 \
           (*(reg8 *) TestCounter_CounterUDB_sC16_counterdp_u3__DP_AUX_CTL_REG)
       #define TestCounter_AUX_CONTROLDP3_PTR \
           ( (reg8 *) TestCounter_CounterUDB_sC16_counterdp_u3__DP_AUX_CTL_REG)
    #endif /* (TestCounter_Resolution == 32) */

#endif  /* (TestCounter_UsingFixedFunction) */

#if (TestCounter_UsingFixedFunction)
    #define TestCounter_STATUS         (*(reg8 *) TestCounter_CounterHW__SR0 )
    /* In Fixed Function Block Status and Mask are the same register */
    #define TestCounter_STATUS_MASK             (*(reg8 *) TestCounter_CounterHW__SR0 )
    #define TestCounter_STATUS_MASK_PTR         ( (reg8 *) TestCounter_CounterHW__SR0 )
    #define TestCounter_CONTROL                 (*(reg8 *) TestCounter_CounterHW__CFG0)
    #define TestCounter_CONTROL_PTR             ( (reg8 *) TestCounter_CounterHW__CFG0)
    #define TestCounter_CONTROL2                (*(reg8 *) TestCounter_CounterHW__CFG1)
    #define TestCounter_CONTROL2_PTR            ( (reg8 *) TestCounter_CounterHW__CFG1)
    #if (CY_PSOC3 || CY_PSOC5LP)
        #define TestCounter_CONTROL3       (*(reg8 *) TestCounter_CounterHW__CFG2)
        #define TestCounter_CONTROL3_PTR   ( (reg8 *) TestCounter_CounterHW__CFG2)
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */
    #define TestCounter_GLOBAL_ENABLE           (*(reg8 *) TestCounter_CounterHW__PM_ACT_CFG)
    #define TestCounter_GLOBAL_ENABLE_PTR       ( (reg8 *) TestCounter_CounterHW__PM_ACT_CFG)
    #define TestCounter_GLOBAL_STBY_ENABLE      (*(reg8 *) TestCounter_CounterHW__PM_STBY_CFG)
    #define TestCounter_GLOBAL_STBY_ENABLE_PTR  ( (reg8 *) TestCounter_CounterHW__PM_STBY_CFG)
    

    /********************************
    *    Constants
    ********************************/

    /* Fixed Function Block Chosen */
    #define TestCounter_BLOCK_EN_MASK          TestCounter_CounterHW__PM_ACT_MSK
    #define TestCounter_BLOCK_STBY_EN_MASK     TestCounter_CounterHW__PM_STBY_MSK 
    
    /* Control Register Bit Locations */    
    /* As defined in Register Map, part of TMRX_CFG0 register */
    #define TestCounter_CTRL_ENABLE_SHIFT      0x00u
    #define TestCounter_ONESHOT_SHIFT          0x02u
    /* Control Register Bit Masks */
    #define TestCounter_CTRL_ENABLE            ((uint8)((uint8)0x01u << TestCounter_CTRL_ENABLE_SHIFT))         
    #define TestCounter_ONESHOT                ((uint8)((uint8)0x01u << TestCounter_ONESHOT_SHIFT))

    /* Control2 Register Bit Masks */
    /* Set the mask for run mode */
    #if (CY_PSOC5A)
        /* Use CFG1 Mode bits to set run mode */
        #define TestCounter_CTRL_MODE_SHIFT        0x01u    
        #define TestCounter_CTRL_MODE_MASK         ((uint8)((uint8)0x07u << TestCounter_CTRL_MODE_SHIFT))
    #endif /* (CY_PSOC5A) */
    #if (CY_PSOC3 || CY_PSOC5LP)
        /* Use CFG2 Mode bits to set run mode */
        #define TestCounter_CTRL_MODE_SHIFT        0x00u    
        #define TestCounter_CTRL_MODE_MASK         ((uint8)((uint8)0x03u << TestCounter_CTRL_MODE_SHIFT))
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */
    /* Set the mask for interrupt (raw/status register) */
    #define TestCounter_CTRL2_IRQ_SEL_SHIFT     0x00u
    #define TestCounter_CTRL2_IRQ_SEL          ((uint8)((uint8)0x01u << TestCounter_CTRL2_IRQ_SEL_SHIFT))     
    
    /* Status Register Bit Locations */
    #define TestCounter_STATUS_ZERO_SHIFT      0x07u  /* As defined in Register Map, part of TMRX_SR0 register */ 

    /* Status Register Interrupt Enable Bit Locations */
    #define TestCounter_STATUS_ZERO_INT_EN_MASK_SHIFT      (TestCounter_STATUS_ZERO_SHIFT - 0x04u)

    /* Status Register Bit Masks */                           
    #define TestCounter_STATUS_ZERO            ((uint8)((uint8)0x01u << TestCounter_STATUS_ZERO_SHIFT))

    /* Status Register Interrupt Bit Masks*/
    #define TestCounter_STATUS_ZERO_INT_EN_MASK       ((uint8)((uint8)TestCounter_STATUS_ZERO >> 0x04u))
    
    /*RT1 Synch Constants: Applicable for PSoC3 and PSoC5LP */
    #define TestCounter_RT1_SHIFT            0x04u
    #define TestCounter_RT1_MASK             ((uint8)((uint8)0x03u << TestCounter_RT1_SHIFT))  /* Sync TC and CMP bit masks */
    #define TestCounter_SYNC                 ((uint8)((uint8)0x03u << TestCounter_RT1_SHIFT))
    #define TestCounter_SYNCDSI_SHIFT        0x00u
    #define TestCounter_SYNCDSI_MASK         ((uint8)((uint8)0x0Fu << TestCounter_SYNCDSI_SHIFT)) /* Sync all DSI inputs */
    #define TestCounter_SYNCDSI_EN           ((uint8)((uint8)0x0Fu << TestCounter_SYNCDSI_SHIFT)) /* Sync all DSI inputs */
    
#else /* !TestCounter_UsingFixedFunction */
    #define TestCounter_STATUS               (* (reg8 *) TestCounter_CounterUDB_sSTSReg_stsreg__STATUS_REG )
    #define TestCounter_STATUS_PTR           (  (reg8 *) TestCounter_CounterUDB_sSTSReg_stsreg__STATUS_REG )
    #define TestCounter_STATUS_MASK          (* (reg8 *) TestCounter_CounterUDB_sSTSReg_stsreg__MASK_REG )
    #define TestCounter_STATUS_MASK_PTR      (  (reg8 *) TestCounter_CounterUDB_sSTSReg_stsreg__MASK_REG )
    #define TestCounter_STATUS_AUX_CTRL      (*(reg8 *) TestCounter_CounterUDB_sSTSReg_stsreg__STATUS_AUX_CTL_REG)
    #define TestCounter_STATUS_AUX_CTRL_PTR  ( (reg8 *) TestCounter_CounterUDB_sSTSReg_stsreg__STATUS_AUX_CTL_REG)
    #define TestCounter_CONTROL              (* (reg8 *) TestCounter_CounterUDB_sCTRLReg_ctrlreg__CONTROL_REG )
    #define TestCounter_CONTROL_PTR          (  (reg8 *) TestCounter_CounterUDB_sCTRLReg_ctrlreg__CONTROL_REG )


    /********************************
    *    Constants
    ********************************/
    /* Control Register Bit Locations */
    #define TestCounter_CTRL_CAPMODE0_SHIFT    0x03u       /* As defined by Verilog Implementation */
    #define TestCounter_CTRL_RESET_SHIFT       0x06u       /* As defined by Verilog Implementation */
    #define TestCounter_CTRL_ENABLE_SHIFT      0x07u       /* As defined by Verilog Implementation */
    /* Control Register Bit Masks */
    #define TestCounter_CTRL_CMPMODE_MASK      0x07u 
    #define TestCounter_CTRL_CAPMODE_MASK      0x03u  
    #define TestCounter_CTRL_RESET             ((uint8)((uint8)0x01u << TestCounter_CTRL_RESET_SHIFT))  
    #define TestCounter_CTRL_ENABLE            ((uint8)((uint8)0x01u << TestCounter_CTRL_ENABLE_SHIFT)) 

    /* Status Register Bit Locations */
    #define TestCounter_STATUS_CMP_SHIFT       0x00u       /* As defined by Verilog Implementation */
    #define TestCounter_STATUS_ZERO_SHIFT      0x01u       /* As defined by Verilog Implementation */
    #define TestCounter_STATUS_OVERFLOW_SHIFT  0x02u       /* As defined by Verilog Implementation */
    #define TestCounter_STATUS_UNDERFLOW_SHIFT 0x03u       /* As defined by Verilog Implementation */
    #define TestCounter_STATUS_CAPTURE_SHIFT   0x04u       /* As defined by Verilog Implementation */
    #define TestCounter_STATUS_FIFOFULL_SHIFT  0x05u       /* As defined by Verilog Implementation */
    #define TestCounter_STATUS_FIFONEMP_SHIFT  0x06u       /* As defined by Verilog Implementation */
    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define TestCounter_STATUS_CMP_INT_EN_MASK_SHIFT       TestCounter_STATUS_CMP_SHIFT       
    #define TestCounter_STATUS_ZERO_INT_EN_MASK_SHIFT      TestCounter_STATUS_ZERO_SHIFT      
    #define TestCounter_STATUS_OVERFLOW_INT_EN_MASK_SHIFT  TestCounter_STATUS_OVERFLOW_SHIFT  
    #define TestCounter_STATUS_UNDERFLOW_INT_EN_MASK_SHIFT TestCounter_STATUS_UNDERFLOW_SHIFT 
    #define TestCounter_STATUS_CAPTURE_INT_EN_MASK_SHIFT   TestCounter_STATUS_CAPTURE_SHIFT   
    #define TestCounter_STATUS_FIFOFULL_INT_EN_MASK_SHIFT  TestCounter_STATUS_FIFOFULL_SHIFT  
    #define TestCounter_STATUS_FIFONEMP_INT_EN_MASK_SHIFT  TestCounter_STATUS_FIFONEMP_SHIFT  
    /* Status Register Bit Masks */                
    #define TestCounter_STATUS_CMP             ((uint8)((uint8)0x01u << TestCounter_STATUS_CMP_SHIFT))  
    #define TestCounter_STATUS_ZERO            ((uint8)((uint8)0x01u << TestCounter_STATUS_ZERO_SHIFT)) 
    #define TestCounter_STATUS_OVERFLOW        ((uint8)((uint8)0x01u << TestCounter_STATUS_OVERFLOW_SHIFT)) 
    #define TestCounter_STATUS_UNDERFLOW       ((uint8)((uint8)0x01u << TestCounter_STATUS_UNDERFLOW_SHIFT)) 
    #define TestCounter_STATUS_CAPTURE         ((uint8)((uint8)0x01u << TestCounter_STATUS_CAPTURE_SHIFT)) 
    #define TestCounter_STATUS_FIFOFULL        ((uint8)((uint8)0x01u << TestCounter_STATUS_FIFOFULL_SHIFT))
    #define TestCounter_STATUS_FIFONEMP        ((uint8)((uint8)0x01u << TestCounter_STATUS_FIFONEMP_SHIFT))
    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define TestCounter_STATUS_CMP_INT_EN_MASK            TestCounter_STATUS_CMP                    
    #define TestCounter_STATUS_ZERO_INT_EN_MASK           TestCounter_STATUS_ZERO            
    #define TestCounter_STATUS_OVERFLOW_INT_EN_MASK       TestCounter_STATUS_OVERFLOW        
    #define TestCounter_STATUS_UNDERFLOW_INT_EN_MASK      TestCounter_STATUS_UNDERFLOW       
    #define TestCounter_STATUS_CAPTURE_INT_EN_MASK        TestCounter_STATUS_CAPTURE         
    #define TestCounter_STATUS_FIFOFULL_INT_EN_MASK       TestCounter_STATUS_FIFOFULL        
    #define TestCounter_STATUS_FIFONEMP_INT_EN_MASK       TestCounter_STATUS_FIFONEMP         
    

    /* StatusI Interrupt Enable bit Location in the Auxilliary Control Register */
    #define TestCounter_STATUS_ACTL_INT_EN     0x10u /* As defined for the ACTL Register */
    
    /* Datapath Auxillary Control Register definitions */
    #define TestCounter_AUX_CTRL_FIFO0_CLR         0x01u   /* As defined by Register map */
    #define TestCounter_AUX_CTRL_FIFO1_CLR         0x02u   /* As defined by Register map */
    #define TestCounter_AUX_CTRL_FIFO0_LVL         0x04u   /* As defined by Register map */
    #define TestCounter_AUX_CTRL_FIFO1_LVL         0x08u   /* As defined by Register map */
    #define TestCounter_STATUS_ACTL_INT_EN_MASK    0x10u   /* As defined for the ACTL Register */
    
#endif /* TestCounter_UsingFixedFunction */

#endif  /* CY_COUNTER_TestCounter_H */


/* [] END OF FILE */

