/*******************************************************************************
* File Name: V10.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_V10_H) /* Pins V10_H */
#define CY_PINS_V10_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "V10_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 V10__PORT == 15 && ((V10__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    V10_Write(uint8 value);
void    V10_SetDriveMode(uint8 mode);
uint8   V10_ReadDataReg(void);
uint8   V10_Read(void);
void    V10_SetInterruptMode(uint16 position, uint16 mode);
uint8   V10_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the V10_SetDriveMode() function.
     *  @{
     */
        #define V10_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define V10_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define V10_DM_RES_UP          PIN_DM_RES_UP
        #define V10_DM_RES_DWN         PIN_DM_RES_DWN
        #define V10_DM_OD_LO           PIN_DM_OD_LO
        #define V10_DM_OD_HI           PIN_DM_OD_HI
        #define V10_DM_STRONG          PIN_DM_STRONG
        #define V10_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define V10_MASK               V10__MASK
#define V10_SHIFT              V10__SHIFT
#define V10_WIDTH              1u

/* Interrupt constants */
#if defined(V10__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in V10_SetInterruptMode() function.
     *  @{
     */
        #define V10_INTR_NONE      (uint16)(0x0000u)
        #define V10_INTR_RISING    (uint16)(0x0001u)
        #define V10_INTR_FALLING   (uint16)(0x0002u)
        #define V10_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define V10_INTR_MASK      (0x01u) 
#endif /* (V10__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define V10_PS                     (* (reg8 *) V10__PS)
/* Data Register */
#define V10_DR                     (* (reg8 *) V10__DR)
/* Port Number */
#define V10_PRT_NUM                (* (reg8 *) V10__PRT) 
/* Connect to Analog Globals */                                                  
#define V10_AG                     (* (reg8 *) V10__AG)                       
/* Analog MUX bux enable */
#define V10_AMUX                   (* (reg8 *) V10__AMUX) 
/* Bidirectional Enable */                                                        
#define V10_BIE                    (* (reg8 *) V10__BIE)
/* Bit-mask for Aliased Register Access */
#define V10_BIT_MASK               (* (reg8 *) V10__BIT_MASK)
/* Bypass Enable */
#define V10_BYP                    (* (reg8 *) V10__BYP)
/* Port wide control signals */                                                   
#define V10_CTL                    (* (reg8 *) V10__CTL)
/* Drive Modes */
#define V10_DM0                    (* (reg8 *) V10__DM0) 
#define V10_DM1                    (* (reg8 *) V10__DM1)
#define V10_DM2                    (* (reg8 *) V10__DM2) 
/* Input Buffer Disable Override */
#define V10_INP_DIS                (* (reg8 *) V10__INP_DIS)
/* LCD Common or Segment Drive */
#define V10_LCD_COM_SEG            (* (reg8 *) V10__LCD_COM_SEG)
/* Enable Segment LCD */
#define V10_LCD_EN                 (* (reg8 *) V10__LCD_EN)
/* Slew Rate Control */
#define V10_SLW                    (* (reg8 *) V10__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define V10_PRTDSI__CAPS_SEL       (* (reg8 *) V10__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define V10_PRTDSI__DBL_SYNC_IN    (* (reg8 *) V10__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define V10_PRTDSI__OE_SEL0        (* (reg8 *) V10__PRTDSI__OE_SEL0) 
#define V10_PRTDSI__OE_SEL1        (* (reg8 *) V10__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define V10_PRTDSI__OUT_SEL0       (* (reg8 *) V10__PRTDSI__OUT_SEL0) 
#define V10_PRTDSI__OUT_SEL1       (* (reg8 *) V10__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define V10_PRTDSI__SYNC_OUT       (* (reg8 *) V10__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(V10__SIO_CFG)
    #define V10_SIO_HYST_EN        (* (reg8 *) V10__SIO_HYST_EN)
    #define V10_SIO_REG_HIFREQ     (* (reg8 *) V10__SIO_REG_HIFREQ)
    #define V10_SIO_CFG            (* (reg8 *) V10__SIO_CFG)
    #define V10_SIO_DIFF           (* (reg8 *) V10__SIO_DIFF)
#endif /* (V10__SIO_CFG) */

/* Interrupt Registers */
#if defined(V10__INTSTAT)
    #define V10_INTSTAT            (* (reg8 *) V10__INTSTAT)
    #define V10_SNAP               (* (reg8 *) V10__SNAP)
    
	#define V10_0_INTTYPE_REG 		(* (reg8 *) V10__0__INTTYPE)
#endif /* (V10__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_V10_H */


/* [] END OF FILE */
