/*******************************************************************************
* File Name: V11.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_V11_H) /* Pins V11_H */
#define CY_PINS_V11_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "V11_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 V11__PORT == 15 && ((V11__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    V11_Write(uint8 value);
void    V11_SetDriveMode(uint8 mode);
uint8   V11_ReadDataReg(void);
uint8   V11_Read(void);
void    V11_SetInterruptMode(uint16 position, uint16 mode);
uint8   V11_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the V11_SetDriveMode() function.
     *  @{
     */
        #define V11_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define V11_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define V11_DM_RES_UP          PIN_DM_RES_UP
        #define V11_DM_RES_DWN         PIN_DM_RES_DWN
        #define V11_DM_OD_LO           PIN_DM_OD_LO
        #define V11_DM_OD_HI           PIN_DM_OD_HI
        #define V11_DM_STRONG          PIN_DM_STRONG
        #define V11_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define V11_MASK               V11__MASK
#define V11_SHIFT              V11__SHIFT
#define V11_WIDTH              1u

/* Interrupt constants */
#if defined(V11__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in V11_SetInterruptMode() function.
     *  @{
     */
        #define V11_INTR_NONE      (uint16)(0x0000u)
        #define V11_INTR_RISING    (uint16)(0x0001u)
        #define V11_INTR_FALLING   (uint16)(0x0002u)
        #define V11_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define V11_INTR_MASK      (0x01u) 
#endif /* (V11__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define V11_PS                     (* (reg8 *) V11__PS)
/* Data Register */
#define V11_DR                     (* (reg8 *) V11__DR)
/* Port Number */
#define V11_PRT_NUM                (* (reg8 *) V11__PRT) 
/* Connect to Analog Globals */                                                  
#define V11_AG                     (* (reg8 *) V11__AG)                       
/* Analog MUX bux enable */
#define V11_AMUX                   (* (reg8 *) V11__AMUX) 
/* Bidirectional Enable */                                                        
#define V11_BIE                    (* (reg8 *) V11__BIE)
/* Bit-mask for Aliased Register Access */
#define V11_BIT_MASK               (* (reg8 *) V11__BIT_MASK)
/* Bypass Enable */
#define V11_BYP                    (* (reg8 *) V11__BYP)
/* Port wide control signals */                                                   
#define V11_CTL                    (* (reg8 *) V11__CTL)
/* Drive Modes */
#define V11_DM0                    (* (reg8 *) V11__DM0) 
#define V11_DM1                    (* (reg8 *) V11__DM1)
#define V11_DM2                    (* (reg8 *) V11__DM2) 
/* Input Buffer Disable Override */
#define V11_INP_DIS                (* (reg8 *) V11__INP_DIS)
/* LCD Common or Segment Drive */
#define V11_LCD_COM_SEG            (* (reg8 *) V11__LCD_COM_SEG)
/* Enable Segment LCD */
#define V11_LCD_EN                 (* (reg8 *) V11__LCD_EN)
/* Slew Rate Control */
#define V11_SLW                    (* (reg8 *) V11__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define V11_PRTDSI__CAPS_SEL       (* (reg8 *) V11__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define V11_PRTDSI__DBL_SYNC_IN    (* (reg8 *) V11__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define V11_PRTDSI__OE_SEL0        (* (reg8 *) V11__PRTDSI__OE_SEL0) 
#define V11_PRTDSI__OE_SEL1        (* (reg8 *) V11__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define V11_PRTDSI__OUT_SEL0       (* (reg8 *) V11__PRTDSI__OUT_SEL0) 
#define V11_PRTDSI__OUT_SEL1       (* (reg8 *) V11__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define V11_PRTDSI__SYNC_OUT       (* (reg8 *) V11__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(V11__SIO_CFG)
    #define V11_SIO_HYST_EN        (* (reg8 *) V11__SIO_HYST_EN)
    #define V11_SIO_REG_HIFREQ     (* (reg8 *) V11__SIO_REG_HIFREQ)
    #define V11_SIO_CFG            (* (reg8 *) V11__SIO_CFG)
    #define V11_SIO_DIFF           (* (reg8 *) V11__SIO_DIFF)
#endif /* (V11__SIO_CFG) */

/* Interrupt Registers */
#if defined(V11__INTSTAT)
    #define V11_INTSTAT            (* (reg8 *) V11__INTSTAT)
    #define V11_SNAP               (* (reg8 *) V11__SNAP)
    
	#define V11_0_INTTYPE_REG 		(* (reg8 *) V11__0__INTTYPE)
#endif /* (V11__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_V11_H */


/* [] END OF FILE */
