/*******************************************************************************
* File Name: V9.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_V9_H) /* Pins V9_H */
#define CY_PINS_V9_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "V9_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 V9__PORT == 15 && ((V9__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    V9_Write(uint8 value);
void    V9_SetDriveMode(uint8 mode);
uint8   V9_ReadDataReg(void);
uint8   V9_Read(void);
void    V9_SetInterruptMode(uint16 position, uint16 mode);
uint8   V9_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the V9_SetDriveMode() function.
     *  @{
     */
        #define V9_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define V9_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define V9_DM_RES_UP          PIN_DM_RES_UP
        #define V9_DM_RES_DWN         PIN_DM_RES_DWN
        #define V9_DM_OD_LO           PIN_DM_OD_LO
        #define V9_DM_OD_HI           PIN_DM_OD_HI
        #define V9_DM_STRONG          PIN_DM_STRONG
        #define V9_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define V9_MASK               V9__MASK
#define V9_SHIFT              V9__SHIFT
#define V9_WIDTH              1u

/* Interrupt constants */
#if defined(V9__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in V9_SetInterruptMode() function.
     *  @{
     */
        #define V9_INTR_NONE      (uint16)(0x0000u)
        #define V9_INTR_RISING    (uint16)(0x0001u)
        #define V9_INTR_FALLING   (uint16)(0x0002u)
        #define V9_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define V9_INTR_MASK      (0x01u) 
#endif /* (V9__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define V9_PS                     (* (reg8 *) V9__PS)
/* Data Register */
#define V9_DR                     (* (reg8 *) V9__DR)
/* Port Number */
#define V9_PRT_NUM                (* (reg8 *) V9__PRT) 
/* Connect to Analog Globals */                                                  
#define V9_AG                     (* (reg8 *) V9__AG)                       
/* Analog MUX bux enable */
#define V9_AMUX                   (* (reg8 *) V9__AMUX) 
/* Bidirectional Enable */                                                        
#define V9_BIE                    (* (reg8 *) V9__BIE)
/* Bit-mask for Aliased Register Access */
#define V9_BIT_MASK               (* (reg8 *) V9__BIT_MASK)
/* Bypass Enable */
#define V9_BYP                    (* (reg8 *) V9__BYP)
/* Port wide control signals */                                                   
#define V9_CTL                    (* (reg8 *) V9__CTL)
/* Drive Modes */
#define V9_DM0                    (* (reg8 *) V9__DM0) 
#define V9_DM1                    (* (reg8 *) V9__DM1)
#define V9_DM2                    (* (reg8 *) V9__DM2) 
/* Input Buffer Disable Override */
#define V9_INP_DIS                (* (reg8 *) V9__INP_DIS)
/* LCD Common or Segment Drive */
#define V9_LCD_COM_SEG            (* (reg8 *) V9__LCD_COM_SEG)
/* Enable Segment LCD */
#define V9_LCD_EN                 (* (reg8 *) V9__LCD_EN)
/* Slew Rate Control */
#define V9_SLW                    (* (reg8 *) V9__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define V9_PRTDSI__CAPS_SEL       (* (reg8 *) V9__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define V9_PRTDSI__DBL_SYNC_IN    (* (reg8 *) V9__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define V9_PRTDSI__OE_SEL0        (* (reg8 *) V9__PRTDSI__OE_SEL0) 
#define V9_PRTDSI__OE_SEL1        (* (reg8 *) V9__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define V9_PRTDSI__OUT_SEL0       (* (reg8 *) V9__PRTDSI__OUT_SEL0) 
#define V9_PRTDSI__OUT_SEL1       (* (reg8 *) V9__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define V9_PRTDSI__SYNC_OUT       (* (reg8 *) V9__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(V9__SIO_CFG)
    #define V9_SIO_HYST_EN        (* (reg8 *) V9__SIO_HYST_EN)
    #define V9_SIO_REG_HIFREQ     (* (reg8 *) V9__SIO_REG_HIFREQ)
    #define V9_SIO_CFG            (* (reg8 *) V9__SIO_CFG)
    #define V9_SIO_DIFF           (* (reg8 *) V9__SIO_DIFF)
#endif /* (V9__SIO_CFG) */

/* Interrupt Registers */
#if defined(V9__INTSTAT)
    #define V9_INTSTAT            (* (reg8 *) V9__INTSTAT)
    #define V9_SNAP               (* (reg8 *) V9__SNAP)
    
	#define V9_0_INTTYPE_REG 		(* (reg8 *) V9__0__INTTYPE)
#endif /* (V9__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_V9_H */


/* [] END OF FILE */
