/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/

#include <MPR03X.h>
#include <project.h>

unsigned char data = 0;
unsigned char* pdata = &data;

unsigned char MPR_Init(unsigned char i2c_address)
{       
    if(MPR_WriteRegister(i2c_address, ELECTRODE_CONFIG_REG, 0x00)) // Stop cap sense IC
    {
        MPR_ReadRegister(i2c_address, ELECTRODE_CONFIG_REG, pdata);
        if(data != 0x00)
        {
            return 0;
        }
        
        if(MPR_WriteRegister(i2c_address, FILTER_CONFIG_REG, 0x24)) // 16ms detection sample interval, 4 samples for second level filter, 0.5us charge time
        {
            MPR_ReadRegister(i2c_address, FILTER_CONFIG_REG, pdata);
            if(data != 0x24)
            {
                return 0;
            }
            
            if(MPR_WriteRegister(i2c_address, AFE_CONFIG_REG, 0x10)) // 6 AFE samples, 16 uA charge current
            {
                MPR_ReadRegister(i2c_address, AFE_CONFIG_REG, pdata);
                if(data != 0x10)
                {
                    return 0;
                }
                
                if(MPR_WriteRegister(i2c_address, ELECTRODE_CONFIG_REG, 0x01)) // Start cap sense IC
                {
                    MPR_ReadRegister(i2c_address, ELECTRODE_CONFIG_REG, pdata);
                    if(data != 0x01)
                    { 
                        return 0;
                    }
                                 
                    return 1;
                   
                }
            }
        }  
    }
        
    return 0;
}

unsigned char MPR_WriteRegister(unsigned char i2c_address, unsigned char reg, unsigned char data)
{
    //TimeoutTimer_Start();
    //TimeoutTimer_WriteCounter(0);
    
    if( I2C_MSTR_NO_ERROR == I2C_MasterSendStart(i2c_address, WR_CMD))
    {
        if( I2C_MSTR_NO_ERROR == I2C_MasterWriteByte(reg) )
        {
            if( I2C_MSTR_NO_ERROR == I2C_MasterWriteByte(data) )
            {
                if( I2C_MSTR_NO_ERROR == I2C_MasterSendStop() )
                {
                    //TimeoutTimer_Stop();
                    CyDelay(1);
                    return 1; // Success!
                }
            }
        }
    } 
   
    I2C_MasterSendStop();
    return 0; // Fail
}

unsigned char MPR_ReadRegister(unsigned char i2c_address, unsigned char reg, unsigned char* pdata)
{
    if( I2C_MSTR_NO_ERROR == I2C_MasterSendStart(i2c_address, WR_CMD))
    {
        if( I2C_MSTR_NO_ERROR == I2C_MasterWriteByte(reg) )
        {
            if( I2C_MSTR_NO_ERROR == I2C_MasterSendRestart(i2c_address, RD_CMD) )
            {                
                unsigned char temp;
                temp = I2C_MasterReadByte(I2C_ACK_DATA);
                *pdata = temp;
                
                if( I2C_MSTR_NO_ERROR == I2C_MasterSendStop() )
                {
                    CyDelay(1);
                    return 1; // Success!
                }
            }
        }
    }
    
    I2C_MasterSendStop();
    return 0; // Fail!    
}

unsigned char MPR_GetCapData(unsigned char i2c_address, unsigned int* pCapVal)
{
    
    // Get the capacitance value.
    CyDelay(100);
    unsigned char LSB = 0;
    unsigned char MSB = 0;

    if( MPR_ReadRegister(i2c_address, ELE0_FILT_LOW_REG, pdata) )
    {
        LSB = data;
        if( MPR_ReadRegister(i2c_address, ELE0_FILT_HIGH_REG, pdata) )
        {
            MSB = data;
            *pCapVal = (MSB << 8) | LSB;
            return 1;
        }        
    }
    
    return 0;  
}


/* [] END OF FILE */
