/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/

#ifndef MAIN_H
#define MAIN_H
    
#include <project.h>
    
// Typedefs
typedef struct
{
    double DUT_MaxCurrent;
    char Current_status[25];
    unsigned char DUT_DeviceClass;      // The device class of the attached DUT.
    unsigned char DUT_SingleWireComm;   // Indicate if the single wire comm hardware is loaded.
    unsigned char CAN_NumRX;            // The number of CAN packets recieved by the tester from the sensor during the CAN test.
    char CAN_status[25];                // The status of the CAN test.
    char REV_status[25];                // The status of the Reverse Input test.
    double Vdisp_NO_LOAD;               // The No Load voltage of the display+.
    double Idisp_TRIP;                  // The current at which display+ < 0.5V.
    char DISP_status[25];               // The status of the Display Power test.
    double Ialarm_TRIP;                 // The current at which the alarm current is cut off.
    char ALARM_status[25];              // The status of the Alarm Power test.
    double Vsupply;
    double Vdut;
    double Vcore;
    double Vovp;
    double Vddr;
    double Vddr_dl;
    double Vanalog;
    char VOLT_status[25];
    char DETECT_status[25]; 
    int16 CH1I_max;
    int16 CH1Q_max;
    int16 CH2I_max;
    int16 CH2Q_max;
    uint16 CH1I_phase;
    uint16 CH1Q_phase;
    uint16 CH2I_phase;
    uint16 CH2Q_phase;
    char IQ_status[25];
    double SingleWirePWM_TimeHigh;
    double SingleWirePWM_TimeLow;    
    char SingleWire_status[25];
    int16 TotalTestTime; // ms
} TEST_RESULTS;

typedef struct
{
    double DUT_MaxCurrent;
    char Current_status[25];
    unsigned char Revision;
    unsigned char LowFreqLock;
    unsigned char MidFreqLock;
    unsigned char HighFreqLock;
    double LowFreqTxPower;
    double MidFreqTxPower;
    double HighFreqTxPower;
    char PLL_status[25];
    char TxPower_status[25];
    char CapSenseTop_status[25];
    char CapSenseBottom_status[25];
    int16 TotalTestTime; // ms
} ANT_TEST_RESULTS;

typedef struct
{
    double range;       // Feet
    double angle;       // Degrees
    double amplitude;   // counter
    double frequency;   // Hz
    double phase;       // Degrees
} TARGET;

typedef struct
{
    uint16 X;
    int16 Y;   
} POINT;
    

typedef enum STATE_MACHINE{
    START_PROC_TEST,
    START_ANT_TEST,
    RUN,
    WAIT,
    CAN_COMM_TEST,
    REV_INPUT_TEST,
    DISPLAY_PWR_TEST,
    ALARM_PWR_TEST,
    TARGET_SIM_TEST,
    TARGET_DETECT_TEST,
    VOLTAGE_TEST,
    IQ_TEST,
    SINGLE_WIRE_TEST,
    EXIT_PROCESSOR_TEST,
    CAP_SENSE_TEST,
    ANT_FREQ_TEST,
    EXIT_ANTENNA_TEST
} STATES;

// Processor board prototypes
void SetTarget(TARGET*);
void CanCommTest(void);
void RevInputTest(void);
void DisplayPowerTest(void);
void AlarmPowerTest(void);
void TargetSimTest(void);
void TargetDetectTest(void);
void ProcessorVoltageTest(void);
void IQ_Test(void);
void SingleWireCommTest(void);
void GenerateSineWave1Table(unsigned int);
void GenerateSineWave2Table(unsigned int);
void GenerateSineWave3Table(unsigned int);
void GenerateSineWave4Table(unsigned int);
unsigned int CalculateFrequency(void);
unsigned int CalculatePwmPeriod(void);
void ResetAllDMAs(void);
void RevertToFactoryDefaults(void);
double GetProcessorCurrent(void);
void ShowProcessorTestResults(void);

// Antenna board prototypes
double GetAntennaCurrent(void);
unsigned char GetAntennaRev(void);
void CapSenseTest(void);
void AntennaFreqTest(void);
void ShowAntennaTestResults(void);

// Misc.
double GetInputVoltage(void);
CY_ISR_PROTO(COMM_ISR);
CY_ISR_PROTO(TIMEOUT_ISR);

// Analog Mux Channels
#define V0_Chan      0
#define V1_Chan      1
#define V2_Chan      2
#define V3_Chan      3
#define V4_Chan      4
#define V5_Chan      5
#define V6_Chan      6
#define V7_Chan      7
#define V8_Chan      8
#define V9_Chan      9
#define V10_Chan     10
#define V11_Chan     11
#define Ialarm_Chan  12
#define Idut_Chan    13
#define Idisp_Chan   14
#define Vin_Chan     15
#define Vdisp_Chan   16
#define Iant_Chan    17
#define BgaAna1_Chan 18
#define BgaAna2_Chan 19
#define AntRev_Chan  20

// Misc.
#define FW_VERSION          1.0
#define ADC_RESOLUTION      (3.3/65535.0)
#define AMPLITUDE_MAX       140
#define DEBOUNCE            10000

// Maximum allowed PCA current
#define MAX_PROC_CURRENT    0.250
#define MAX_ANT_CURRENT     0.250

// Display Power Test Thresholds
#define DISP_VOLT_MIN       7.5     // Volts
#define DISP_ITRIP_MIN      0.300   // Amps
#define DISP_ITRIP_MAX      0.500   // Amps

// Alarm Power Test Thresholds
#define ALARM_ITRIP_MIN     0.850   // Amps
#define ALARM_ITRIP_MAX     1.150   // Amps 

// Voltage Test Thresholds
#define VSUP_MIN    5.225   // Volts (5.0-5%)
#define VSUP_MAX    13.0    // Volts
#define VDUT_MIN    3.135   // Volts (3.3-5%)
#define VDUT_MAX    3.465   // Volts (3.3+5%)
#define VCORE_MIN   3.135   // Volts (3.3-5%)
#define VCORE_MAX   3.465   // Volts (3.3+5%)
#define VDDR_MIN    1.71    // Volts (1.8-5%)
#define VDDR_MAX    1.89    // Volts (1.8+5%)
#define VDL_MIN     1.71    // Volts (1.8-5%)
#define VDL_MAX     1.89    // Volts (1.8+5%)
#define VANA_MIN    3.135   // Volts (3.3-5%)
#define VANA_MAX    3.465   // Volts (3.3+5%) 
#define VOVP_MIN    8.0     // Volts
#define VOVP_MAX    36.0    // Volts

// Target Angle Tolerance
#define ANGLE_TOLERANCE     5   // Degrees

// Target Range Tolerance
#define RANGE_TOLERANCE     2   // Feet

// IQ Test Thresholds
#define IQ_AMPLITUDE_MIN    1200    
#define IQ_AMPLITUDE_MAX    1700
#define PHASE_TOLERANCE     10     

// Single Wire Comm Tolerance
#define COMM_TOLERANCE      2   // ms

// BGT24MTR12 TX Power Minimum
#define TX_PWR_MIN  0.400   // Volts

// Chip Selects
#define DUT     0
#define TESTER  1

#endif

/* [] END OF FILE */
